#ifndef EFL_GENERATED_ECORE_AUDIO_IN_HH
#define EFL_GENERATED_ECORE_AUDIO_IN_HH

#include <Eo.h>
#include <Eo.hh>

extern "C"
{
#include "ecore_audio_in.eo.h"
}

#include "ecore_audio.eo.hh"

struct ecore_audio_in
      : ecore_audio
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit ecore_audio_in(Eo* eo)
      : ecore_audio(eo)
   {}

   ecore_audio_in(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : ecore_audio_in(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   ecore_audio_in(ecore_audio_in const& other)
      : ecore_audio(eo_ref(other._eo_ptr()))
   {}

   ~ecore_audio_in() {}

   /// @brief Read from the input
   ///
   /// @since 1.8
   ///
   /// @param buf 
   /// @param len 
   ///
   ssize_t read(void * buf, size_t len) const
   {
      ssize_t _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::ecore_audio_obj_in_read(buf, len));
      return _tmp_ret;
   }

   /// @brief Internal read function
   ///
   /// @since 1.8
   ///
   /// @param buf 
   /// @param len 
   ///
   ssize_t read_internal(void * buf, size_t len) const
   {
      ssize_t _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::ecore_audio_obj_in_read_internal(buf, len));
      return _tmp_ret;
   }

   /// @brief Seek within the input
   ///
   /// @since 1.8
   ///
   /// @param offs 
   /// @param mode 
   ///
   double seek(double offs, int mode) const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::ecore_audio_obj_in_seek(offs, mode));
      return _tmp_ret;
   }

   /// @brief Get the playback speed of the input.
   ///
   /// @since 1.8
   ///
   /// @param speed 
   ///
   double speed_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::ecore_audio_obj_in_speed_get());
      return _tmp_ret;
   }

   /// @brief Set the playback speed of the input.
   ///
   /// @since 1.8
   ///
   /// @param speed 
   ///
   void speed_set(double speed) const
   {
      eo_do(_eo_ptr(), ::ecore_audio_obj_in_speed_set(speed));
   }

   /// @brief Get the he sample-rate of the input
   ///
   /// @since 1.8
   ///
   /// @param samplerate 
   ///
   int samplerate_get() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::ecore_audio_obj_in_samplerate_get());
      return _tmp_ret;
   }

   /// @brief Set the sample-rate of the input
   ///
   /// @since 1.8
   ///
   /// @param samplerate 
   ///
   void samplerate_set(int samplerate) const
   {
      eo_do(_eo_ptr(), ::ecore_audio_obj_in_samplerate_set(samplerate));
   }

   /// @brief Get the amount of channels the input has
   ///
   /// @since 1.8
   ///
   /// @param channels 
   ///
   int channels_get() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::ecore_audio_obj_in_channels_get());
      return _tmp_ret;
   }

   /// @brief Set the amount of channels the input has
   ///
   /// @since 1.8
   ///
   /// @param channels 
   ///
   void channels_set(int channels) const
   {
      eo_do(_eo_ptr(), ::ecore_audio_obj_in_channels_set(channels));
   }

   /// @brief Get the the preloaded state of the input
   ///
   /// @since 1.8
   ///
   /// @param preloaded 
   ///
   Eina_Bool preloaded_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::ecore_audio_obj_in_preloaded_get());
      return _tmp_ret;
   }

   /// @brief Set the preloaded state of the input
   ///
   /// @since 1.8
   ///
   /// @param preloaded 
   ///
   void preloaded_set(Eina_Bool preloaded) const
   {
      eo_do(_eo_ptr(), ::ecore_audio_obj_in_preloaded_set(preloaded));
   }

   /// @brief Get the looped state of the input
   ///
   /// @since 1.8
   ///
   /// @param looped 
   ///
   Eina_Bool looped_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::ecore_audio_obj_in_looped_get());
      return _tmp_ret;
   }

   /// @brief Set the looped state of the input
   ///
   /// If the input is looped and reaches the end it will start from the
   /// beginning again. At the same time the event @ref ECORE_AUDIO_EV_IN_LOOPED
   /// will be emitted
   ///
   /// @since 1.8
   ///
   /// @param looped 
   ///
   void looped_set(Eina_Bool looped) const
   {
      eo_do(_eo_ptr(), ::ecore_audio_obj_in_looped_set(looped));
   }

   /// @brief Get the length of the input
   ///
   /// @since 1.8
   ///
   /// @param length 
   ///
   double length_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::ecore_audio_obj_in_length_get());
      return _tmp_ret;
   }

   /// @brief Set the length of the input
   ///
   /// This function is only implemented by some classes
   /// (i.e. ECORE_AUDIO_OBJ_IN_TONE_CLASS)
   ///
   /// @since 1.8
   ///
   /// @param length 
   ///
   void length_set(double length) const
   {
      eo_do(_eo_ptr(), ::ecore_audio_obj_in_length_set(length));
   }

   /// @brief Get the output that this input is attached to
   ///
   /// @since 1.8
   ///
   /// @param output 
   ///
   Eo * output_get() const
   {
      Eo * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::ecore_audio_obj_in_output_get());
      return _tmp_ret;
   }

   /// @brief Get the remaining time of the input
   ///
   /// @since 1.8
   ///
   /// @param remaining 
   ///
   double remaining_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::ecore_audio_obj_in_remaining_get());
      return _tmp_ret;
   }

   static Eo_Class const* _eo_class()
   {
      return(ECORE_AUDIO_OBJ_IN_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ECORE_AUDIO_OBJ_IN_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
ssize_t ecore_audio_in_read_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, void * buf, size_t len)
{
   return static_cast<T*>(self->this_)->read(buf, len);
}

template <typename T>
ssize_t ecore_audio_in_read_internal_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, void * buf, size_t len)
{
   return static_cast<T*>(self->this_)->read_internal(buf, len);
}

template <typename T>
double ecore_audio_in_seek_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double offs, int mode)
{
   return static_cast<T*>(self->this_)->seek(offs, mode);
}

template <typename T>
double ecore_audio_in_speed_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->speed_get();
}

template <typename T>
void ecore_audio_in_speed_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double speed)
{
   static_cast<T*>(self->this_)->speed_set(speed);
}

template <typename T>
int ecore_audio_in_samplerate_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->samplerate_get();
}

template <typename T>
void ecore_audio_in_samplerate_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int samplerate)
{
   static_cast<T*>(self->this_)->samplerate_set(samplerate);
}

template <typename T>
int ecore_audio_in_channels_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->channels_get();
}

template <typename T>
void ecore_audio_in_channels_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int channels)
{
   static_cast<T*>(self->this_)->channels_set(channels);
}

template <typename T>
Eina_Bool ecore_audio_in_preloaded_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->preloaded_get();
}

template <typename T>
void ecore_audio_in_preloaded_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool preloaded)
{
   static_cast<T*>(self->this_)->preloaded_set(preloaded);
}

template <typename T>
Eina_Bool ecore_audio_in_looped_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->looped_get();
}

template <typename T>
void ecore_audio_in_looped_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool looped)
{
   static_cast<T*>(self->this_)->looped_set(looped);
}

template <typename T>
double ecore_audio_in_length_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->length_get();
}

template <typename T>
void ecore_audio_in_length_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double length)
{
   static_cast<T*>(self->this_)->length_set(length);
}

template <typename T>
Eo * ecore_audio_in_output_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->output_get();
}

template <typename T>
double ecore_audio_in_remaining_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->remaining_get();
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::ecore_audio_in >
{
   template <typename T>
   struct type
   {
      virtual ssize_t read(void * buf, size_t len)
      {
         ssize_t _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::ecore_audio_obj_in_read(buf, len));
         return _tmp_ret;
      }

      virtual ssize_t read_internal(void * buf, size_t len)
      {
         ssize_t _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::ecore_audio_obj_in_read_internal(buf, len));
         return _tmp_ret;
      }

      virtual double seek(double offs, int mode)
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::ecore_audio_obj_in_seek(offs, mode));
         return _tmp_ret;
      }

      virtual double speed_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::ecore_audio_obj_in_speed_get());
         return _tmp_ret;
      }

      virtual void speed_set(double speed)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::ecore_audio_obj_in_speed_set(speed));
      }

      virtual int samplerate_get()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::ecore_audio_obj_in_samplerate_get());
         return _tmp_ret;
      }

      virtual void samplerate_set(int samplerate)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::ecore_audio_obj_in_samplerate_set(samplerate));
      }

      virtual int channels_get()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::ecore_audio_obj_in_channels_get());
         return _tmp_ret;
      }

      virtual void channels_set(int channels)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::ecore_audio_obj_in_channels_set(channels));
      }

      virtual Eina_Bool preloaded_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::ecore_audio_obj_in_preloaded_get());
         return _tmp_ret;
      }

      virtual void preloaded_set(Eina_Bool preloaded)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::ecore_audio_obj_in_preloaded_set(preloaded));
      }

      virtual Eina_Bool looped_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::ecore_audio_obj_in_looped_get());
         return _tmp_ret;
      }

      virtual void looped_set(Eina_Bool looped)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::ecore_audio_obj_in_looped_set(looped));
      }

      virtual double length_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::ecore_audio_obj_in_length_get());
         return _tmp_ret;
      }

      virtual void length_set(double length)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::ecore_audio_obj_in_length_set(length));
      }

      virtual Eo * output_get()
      {
         Eo * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::ecore_audio_obj_in_output_get());
         return _tmp_ret;
      }

      virtual double remaining_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::ecore_audio_obj_in_remaining_get());
         return _tmp_ret;
      }

   };
};


template<>
struct operation_description_class_size< ::ecore_audio_in >
{
   static const int value = 17;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::ecore_audio_in>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::ecore_audio_in_read_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::ecore_audio_obj_in_read);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::ecore_audio_in_read_internal_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::ecore_audio_obj_in_read_internal);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::ecore_audio_in_seek_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::ecore_audio_obj_in_seek);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::ecore_audio_in_speed_get_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::ecore_audio_obj_in_speed_get);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::ecore_audio_in_speed_set_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::ecore_audio_obj_in_speed_set);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::ecore_audio_in_samplerate_get_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::ecore_audio_obj_in_samplerate_get);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::ecore_audio_in_samplerate_set_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::ecore_audio_obj_in_samplerate_set);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::ecore_audio_in_channels_get_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::ecore_audio_obj_in_channels_get);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::ecore_audio_in_channels_set_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::ecore_audio_obj_in_channels_set);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::ecore_audio_in_preloaded_get_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::ecore_audio_obj_in_preloaded_get);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::ecore_audio_in_preloaded_set_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::ecore_audio_obj_in_preloaded_set);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::ecore_audio_in_looped_get_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::ecore_audio_obj_in_looped_get);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::ecore_audio_in_looped_set_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::ecore_audio_obj_in_looped_set);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::ecore_audio_in_length_get_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::ecore_audio_obj_in_length_get);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::ecore_audio_in_length_set_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::ecore_audio_obj_in_length_set);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::ecore_audio_in_output_get_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::ecore_audio_obj_in_output_get);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::ecore_audio_in_remaining_get_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::ecore_audio_obj_in_remaining_get);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::ecore_audio_in >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::ecore_audio_in, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

template<>
struct extension_inheritance< ::ecore_audio_in>
{
   template <typename T>
   struct type
   {
      operator ::ecore_audio_in() const
      {
         return ::ecore_audio_in(eo_ref(static_cast<T const*>(this)->_eo_ptr()));
      }

      ssize_t read(void * buf, size_t len)
      {
         ssize_t _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::ecore_audio_obj_in_read(buf, len));
         return _tmp_ret;
      }

      ssize_t read_internal(void * buf, size_t len)
      {
         ssize_t _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::ecore_audio_obj_in_read_internal(buf, len));
         return _tmp_ret;
      }

      double seek(double offs, int mode)
      {
         double _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::ecore_audio_obj_in_seek(offs, mode));
         return _tmp_ret;
      }

      double speed_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::ecore_audio_obj_in_speed_get());
         return _tmp_ret;
      }

      void speed_set(double speed)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::ecore_audio_obj_in_speed_set(speed));
      }

      int samplerate_get()
      {
         int _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::ecore_audio_obj_in_samplerate_get());
         return _tmp_ret;
      }

      void samplerate_set(int samplerate)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::ecore_audio_obj_in_samplerate_set(samplerate));
      }

      int channels_get()
      {
         int _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::ecore_audio_obj_in_channels_get());
         return _tmp_ret;
      }

      void channels_set(int channels)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::ecore_audio_obj_in_channels_set(channels));
      }

      Eina_Bool preloaded_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::ecore_audio_obj_in_preloaded_get());
         return _tmp_ret;
      }

      void preloaded_set(Eina_Bool preloaded)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::ecore_audio_obj_in_preloaded_set(preloaded));
      }

      Eina_Bool looped_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::ecore_audio_obj_in_looped_get());
         return _tmp_ret;
      }

      void looped_set(Eina_Bool looped)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::ecore_audio_obj_in_looped_set(looped));
      }

      double length_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::ecore_audio_obj_in_length_get());
         return _tmp_ret;
      }

      void length_set(double length)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::ecore_audio_obj_in_length_set(length));
      }

      Eo * output_get()
      {
         Eo * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::ecore_audio_obj_in_output_get());
         return _tmp_ret;
      }

      double remaining_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::ecore_audio_obj_in_remaining_get());
         return _tmp_ret;
      }

   };
};

inline Eo_Class const* get_eo_class(tag<::ecore_audio_in>)
{
   return (ECORE_AUDIO_OBJ_IN_CLASS);
}

} } }
#endif // EFL_GENERATED_ECORE_AUDIO_IN_HH

