#ifndef EFL_GENERATED_EVAS_GRID_HH
#define EFL_GENERATED_EVAS_GRID_HH

#include <Eo.h>
#include <Eo.hh>

extern "C"
{
#include "canvas/evas_grid.eo.h"
}

#include "canvas/evas_smart_clipped.eo.hh"

struct evas_grid
      : evas_smart_clipped
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit evas_grid(Eo* eo)
      : evas_smart_clipped(eo)
   {}

   evas_grid(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : evas_grid(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   evas_grid(evas_grid const& other)
      : evas_smart_clipped(eo_ref(other._eo_ptr()))
   {}

   ~evas_grid() {}

   /// @brief Get an accessor to get random access to the list of children for the grid.
   ///
   /// @note Do not remove or delete objects while walking the list.
   /// @since 1.1
   ///
   Eina_Accessor * accessor_new() const
   {
      Eina_Accessor * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_grid_accessor_new());
      return _tmp_ret;
   }

   /// @brief Faster way to remove all child objects from a grid object.
   ///
   /// @since 1.1
   ///
   /// @param clear if true, it will delete just removed children.
   ///
   void clear(Eina_Bool clear) const
   {
      eo_do(_eo_ptr(), ::evas_obj_grid_clear(clear));
   }

   /// @brief Get an iterator to walk the list of children for the grid.
   ///
   /// @note Do not remove or delete objects while walking the list.
   /// @since 1.1
   ///
   Eina_Iterator * iterator_new() const
   {
      Eina_Iterator * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_grid_iterator_new());
      return _tmp_ret;
   }

   /// @brief Create a grid that is child of a given element @a parent.
   ///
   /// @see evas_object_grid_add()
   /// @since 1.1
   ///
   Evas_Object * add_to() const
   {
      Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_grid_add_to());
      return _tmp_ret;
   }

   /// @brief Remove child from grid.
   ///
   /// @note removing a child will immediately call a walk over children in order
   /// to recalculate numbers of columns and rows. If you plan to remove
   /// all children, use evas_object_grid_clear() instead.
   ///
   /// @return 1 on success, 0 on failure.
   /// @since 1.1
   ///
   /// @param child 
   ///
   Eina_Bool unpack(Evas_Object * child) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_grid_unpack(child));
      return _tmp_ret;
   }

   /// @brief Get the pack options for a grid child
   ///
   /// Get the pack x, y, width and height in virtual coordinates set by
   /// evas_object_grid_pack()
   /// @return 1 on success, 0 on failure.
   /// @since 1.1
   ///
   /// @param child The grid child to query for coordinates
   /// @param[out] x The pointer to where the x coordinate will be returned
   /// @param[out] y The pointer to where the y coordinate will be returned
   /// @param[out] w The pointer to where the width will be returned
   /// @param[out] h The pointer to where the height will be returned
   ///
   Eina_Bool pack_get(Evas_Object * child, int* x, int* y, int* w, int* h) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_grid_pack_get(child, x, y, w, h));
      return _tmp_ret;
   }

   /// @brief Add a new child to a grid object.
   ///
   /// @return 1 on success, 0 on failure.
   /// @since 1.1
   ///
   /// @param child The child object to add.
   /// @param x The virtual x coordinate of the child
   /// @param y The virtual y coordinate of the child
   /// @param w The virtual width of the child
   /// @param h The virtual height of the child
   ///
   Eina_Bool pack(Evas_Object * child, int x, int y, int w, int h) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_grid_pack(child, x, y, w, h));
      return _tmp_ret;
   }

   /// @brief Gets the mirrored mode of the grid.
   ///
   /// @return @c EINA_TRUE if it's a mirrored grid, @c EINA_FALSE otherwise.
   /// @see evas_object_grid_mirrored_set()
   /// @since 1.1
   ///
   /// @param mirrored the mirrored mode to set
   ///
   Eina_Bool mirrored_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_grid_mirrored_get());
      return _tmp_ret;
   }

   /// @brief Sets the mirrored mode of the grid. In mirrored mode the grid items go
   /// from right to left instead of left to right. That is, 0,0 is top right, not
   /// to left.
   ///
   /// @since 1.1
   ///
   /// @param mirrored the mirrored mode to set
   ///
   void mirrored_set(Eina_Bool mirrored) const
   {
      eo_do(_eo_ptr(), ::evas_obj_grid_mirrored_set(mirrored));
   }

   /// @brief Get the current virtual resolution
   ///
   /// @see evas_object_grid_size_set()
   /// @since 1.1
   ///
   /// @param w The virtual horizontal size (resolution) in integer units
   /// @param h The virtual vertical size (resolution) in integer units
   ///
   void size_get(int* w, int* h) const
   {
      eo_do(_eo_ptr(), ::evas_obj_grid_size_get(w, h));
   }

   /// @brief Set the virtual resolution for the grid
   ///
   /// @since 1.1
   ///
   /// @param w The virtual horizontal size (resolution) in integer units
   /// @param h The virtual vertical size (resolution) in integer units
   ///
   void size_set(int w, int h) const
   {
      eo_do(_eo_ptr(), ::evas_obj_grid_size_set(w, h));
   }

   /// @brief Get the list of children for the grid.
   ///
   /// @note This is a duplicate of the list kept by the grid internally.
   /// It's up to the user to destroy it when it no longer needs it.
   /// It's possible to remove objects from the grid when walking this
   /// list, but these removals won't be reflected on it.
   /// @since 1.1
   ///
   Eina_List * children_get() const
   {
      Eina_List * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_grid_children_get());
      return _tmp_ret;
   }

   static Eo_Class const* _eo_class()
   {
      return(EVAS_OBJ_GRID_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(EVAS_OBJ_GRID_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
Eina_Accessor * evas_grid_accessor_new_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->accessor_new();
}

template <typename T>
void evas_grid_clear_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool clear)
{
   static_cast<T*>(self->this_)->clear(clear);
}

template <typename T>
Eina_Iterator * evas_grid_iterator_new_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->iterator_new();
}

template <typename T>
Evas_Object * evas_grid_add_to_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->add_to();
}

template <typename T>
Eina_Bool evas_grid_unpack_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * child)
{
   return static_cast<T*>(self->this_)->unpack(child);
}

template <typename T>
Eina_Bool evas_grid_pack_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * child, int* x, int* y, int* w, int* h)
{
   return static_cast<T*>(self->this_)->pack_get(child, x, y, w, h);
}

template <typename T>
Eina_Bool evas_grid_pack_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * child, int x, int y, int w, int h)
{
   return static_cast<T*>(self->this_)->pack(child, x, y, w, h);
}

template <typename T>
Eina_Bool evas_grid_mirrored_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->mirrored_get();
}

template <typename T>
void evas_grid_mirrored_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool mirrored)
{
   static_cast<T*>(self->this_)->mirrored_set(mirrored);
}

template <typename T>
void evas_grid_size_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int* w, int* h)
{
   static_cast<T*>(self->this_)->size_get(w, h);
}

template <typename T>
void evas_grid_size_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int w, int h)
{
   static_cast<T*>(self->this_)->size_set(w, h);
}

template <typename T>
Eina_List * evas_grid_children_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->children_get();
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::evas_grid >
{
   template <typename T>
   struct type
   {
      virtual Eina_Accessor * accessor_new()
      {
         Eina_Accessor * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_grid_accessor_new());
         return _tmp_ret;
      }

      virtual void clear(Eina_Bool clear)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_grid_clear(clear));
      }

      virtual Eina_Iterator * iterator_new()
      {
         Eina_Iterator * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_grid_iterator_new());
         return _tmp_ret;
      }

      virtual Evas_Object * add_to()
      {
         Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_grid_add_to());
         return _tmp_ret;
      }

      virtual Eina_Bool unpack(Evas_Object * child)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_grid_unpack(child));
         return _tmp_ret;
      }

      virtual Eina_Bool pack_get(Evas_Object * child, int* x, int* y, int* w, int* h)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_grid_pack_get(child, x, y, w, h));
         return _tmp_ret;
      }

      virtual Eina_Bool pack(Evas_Object * child, int x, int y, int w, int h)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_grid_pack(child, x, y, w, h));
         return _tmp_ret;
      }

      virtual Eina_Bool mirrored_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_grid_mirrored_get());
         return _tmp_ret;
      }

      virtual void mirrored_set(Eina_Bool mirrored)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_grid_mirrored_set(mirrored));
      }

      virtual void size_get(int* w, int* h)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_grid_size_get(w, h));
      }

      virtual void size_set(int w, int h)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_grid_size_set(w, h));
      }

      virtual Eina_List * children_get()
      {
         Eina_List * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_grid_children_get());
         return _tmp_ret;
      }

   };
};


template<>
struct operation_description_class_size< ::evas_grid >
{
   static const int value = 12;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::evas_grid>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::evas_grid_accessor_new_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::evas_obj_grid_accessor_new);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::evas_grid_clear_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::evas_obj_grid_clear);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::evas_grid_iterator_new_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::evas_obj_grid_iterator_new);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::evas_grid_add_to_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::evas_obj_grid_add_to);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::evas_grid_unpack_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::evas_obj_grid_unpack);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::evas_grid_pack_get_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::evas_obj_grid_pack_get);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::evas_grid_pack_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::evas_obj_grid_pack);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::evas_grid_mirrored_get_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::evas_obj_grid_mirrored_get);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::evas_grid_mirrored_set_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::evas_obj_grid_mirrored_set);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::evas_grid_size_get_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::evas_obj_grid_size_get);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::evas_grid_size_set_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::evas_obj_grid_size_set);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::evas_grid_children_get_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::evas_obj_grid_children_get);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::evas_grid >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::evas_grid, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

template<>
struct extension_inheritance< ::evas_grid>
{
   template <typename T>
   struct type
   {
      operator ::evas_grid() const
      {
         return ::evas_grid(eo_ref(static_cast<T const*>(this)->_eo_ptr()));
      }

      Eina_Accessor * accessor_new()
      {
         Eina_Accessor * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_grid_accessor_new());
         return _tmp_ret;
      }

      void clear(Eina_Bool clear)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_grid_clear(clear));
      }

      Eina_Iterator * iterator_new()
      {
         Eina_Iterator * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_grid_iterator_new());
         return _tmp_ret;
      }

      Evas_Object * add_to()
      {
         Evas_Object * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_grid_add_to());
         return _tmp_ret;
      }

      Eina_Bool unpack(Evas_Object * child)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_grid_unpack(child));
         return _tmp_ret;
      }

      Eina_Bool pack_get(Evas_Object * child, int* x, int* y, int* w, int* h)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_grid_pack_get(child, x, y, w, h));
         return _tmp_ret;
      }

      Eina_Bool pack(Evas_Object * child, int x, int y, int w, int h)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_grid_pack(child, x, y, w, h));
         return _tmp_ret;
      }

      Eina_Bool mirrored_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_grid_mirrored_get());
         return _tmp_ret;
      }

      void mirrored_set(Eina_Bool mirrored)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_grid_mirrored_set(mirrored));
      }

      void size_get(int* w, int* h)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_grid_size_get(w, h));
      }

      void size_set(int w, int h)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_grid_size_set(w, h));
      }

      Eina_List * children_get()
      {
         Eina_List * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_grid_children_get());
         return _tmp_ret;
      }

   };
};

inline Eo_Class const* get_eo_class(tag<::evas_grid>)
{
   return (EVAS_OBJ_GRID_CLASS);
}

} } }
#endif // EFL_GENERATED_EVAS_GRID_HH

