#ifndef EFL_GENERATED_EVAS_SMART_HH
#define EFL_GENERATED_EVAS_SMART_HH

#include <Eo.h>
#include <Eo.hh>

extern "C"
{
#include "canvas/evas_smart.eo.h"
}

#include "canvas/evas_object.eo.hh"
#include "canvas/evas_signal_interface.eo.hh"

struct evas_smart
      : evas_object,
      efl::eo::detail::extension_inheritance<evas_signal_interface>::type<evas_smart>

{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit evas_smart(Eo* eo)
      : evas_object(eo)
   {}

   evas_smart(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : evas_smart(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   evas_smart(evas_smart const& other)
      : evas_object(eo_ref(other._eo_ptr()))
   {}

   ~evas_smart() {}

   /// @brief No description supplied by the EAPI.
   ///
   void show() const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_show());
   }

   /// @brief No description supplied by the EAPI.
   ///
   /// @param x 
   /// @param y 
   ///
   void move(Evas_Coord x, Evas_Coord y) const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_move(x, y));
   }

   /// @brief Set an smart object @b instance's smart callbacks descriptions.
   ///
   /// @return @c EINA_TRUE on success, @c EINA_FALSE on failure.
   ///
   /// These descriptions are hints to be used by introspection and are
   /// not enforced in any way.
   ///
   /// It will not be checked if instance callbacks descriptions have the
   /// same name as respective possibly registered in the smart object
   /// @b class. Both are kept in different arrays and users of
   /// evas_object_smart_callbacks_descriptions_get() should handle this
   /// case as they wish.
   ///
   /// @note Becase @p descriptions must be @c NULL terminated, and
   /// because a @c NULL name makes little sense, too,
   /// Evas_Smart_Cb_Description::name must @b not be @c NULL.
   ///
   /// @note While instance callbacks descriptions are possible, they are
   /// @b not recommended. Use @b class callbacks descriptions
   /// instead as they make you smart object user's life simpler and
   /// will use less memory, as descriptions and arrays will be
   /// shared among all instances.
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param descriptions @c NULL terminated array with
   /// #Evas_Smart_Cb_Description descriptions. Array elements won't be
   /// modified at run time, but references to them and their contents
   /// will be made, so this array should be kept alive during the whole
   /// object's lifetime.
   ///
   Eina_Bool callbacks_descriptions_set(const Evas_Smart_Cb_Description * descriptions) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_smart_callbacks_descriptions_set(descriptions));
      return _tmp_ret;
   }

   /// @brief Retrieve an smart object's know smart callback descriptions (both
   /// instance and class ones).
   ///
   /// This call searches for registered callback descriptions for both
   /// instance and class of the given smart object. These arrays will be
   /// sorted by Evas_Smart_Cb_Description::name and also @c NULL
   /// terminated, so both @a class_count and @a instance_count can be
   /// ignored, if the caller wishes so. The terminator @c NULL is not
   /// counted in these values.
   ///
   /// @note If just class descriptions are of interest, try
   /// evas_smart_callbacks_descriptions_get() instead.
   ///
   /// @note Use @c NULL pointers on the descriptions/counters you're not
   /// interested in: they'll be ignored by the function.
   ///
   /// @see evas_smart_callbacks_descriptions_get()
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param[out] class_descriptions Where to store class callbacks
   /// descriptions array, if any is known. If no descriptions are
   /// known, @c NULL is returned
   /// @param[out] class_count Returns how many class callbacks descriptions
   /// are known.
   /// @param[out] instance_descriptions Where to store instance callbacks
   /// descriptions array, if any is known. If no descriptions are
   /// known, @c NULL is returned.
   /// @param[out] instance_count Returns how many instance callbacks
   /// descriptions are known.
   ///
   void callbacks_descriptions_get(const Evas_Smart_Cb_Description *** class_descriptions, unsigned int* class_count, const Evas_Smart_Cb_Description *** instance_descriptions, unsigned int* instance_count) const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_callbacks_descriptions_get(class_descriptions, class_count, instance_descriptions, instance_count));
   }

   /// @brief Retrieves an iterator of the member objects of a given Evas smart
   /// object
   ///
   /// @return Returns the iterator of the member objects of @p obj.
   ///
   /// @since 1.8
   ///
   /// @see evas_object_smart_member_add()
   /// @see evas_object_smart_member_del()
   /// @see evas_object_smart_members_get()
   ///
   Eina_Iterator * iterator_new() const
   {
      Eina_Iterator * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_smart_iterator_new());
      return _tmp_ret;
   }

   /// @brief Find callback description for callback called @a name.
   ///
   /// or @c NULL if not found. If parameter is @c NULL, no search
   /// will be done on instance descriptions.
   /// @return reference to description if found, @c NULL if not found.
   ///
   /// @param name name of desired callback, must @b not be @c NULL. The
   /// search have a special case for @a name being the same
   /// pointer as registered with Evas_Smart_Cb_Description, one
   /// can use it to avoid excessive use of strcmp().
   /// @param[out] class_description pointer to return class description or
   /// @c NULL if not found. If parameter is @c NULL, no search will
   /// be done on class descriptions.
   /// @param[out] instance_description pointer to return instance description
   ///
   void callback_description_find(const char * name, const Evas_Smart_Cb_Description ** class_description, const Evas_Smart_Cb_Description ** instance_description) const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_callback_description_find(name, class_description, instance_description));
   }

   /// @brief No description supplied by the EAPI.
   ///
   void hide() const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_hide());
   }

   /// @brief Call the @b calculate() smart function immediately on a given smart
   /// object.
   ///
   /// This will force immediate calculations (see #Evas_Smart_Class)
   /// needed for renderization of this object and, besides, unset the
   /// flag on it telling it needs recalculation for the next rendering
   /// phase.
   ///
   /// @see evas_object_smart_need_recalculate_set()
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   void calculate() const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_calculate());
   }

   /// @brief Instantiates a new smart object described by @p s.
   ///
   /// @return a new #Evas_Object handle
   ///
   /// This is the function one should use when defining the public
   /// function @b adding an instance of the new smart object to a given
   /// canvas. It will take care of setting all of its internals to work
   /// as they should, if the user set things properly, as seem on the
   /// #EVAS_SMART_SUBCLASS_NEW, for example.
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   void add() const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_add());
   }

   /// @brief Set an Evas object as a member of a given smart object.
   ///
   /// Members will automatically be stacked and layered together with the
   /// smart object. The various stacking functions will operate on
   /// members relative to the other members instead of the entire canvas,
   /// since they now live on an exclusive layer (see
   /// evas_object_stack_above(), for more details).
   ///
   /// Any @p smart_obj object's specific implementation of the @c
   /// member_add() smart function will take place too, naturally.
   ///
   /// @see evas_object_smart_member_del()
   /// @see evas_object_smart_members_get()
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param sub_obj The member object
   ///
   void member_add(Evas_Object * sub_obj) const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_member_add(sub_obj));
   }

   /// @brief No description supplied by the EAPI.
   ///
   /// @param w 
   /// @param h 
   ///
   void resize(Evas_Coord w, Evas_Coord h) const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_resize(w, h));
   }

   /// @brief No description supplied by the EAPI.
   ///
   void clip_unset() const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_clip_unset());
   }

   /// @brief Mark smart object as changed, dirty.
   ///
   /// This will flag the given object as needing recalculation,
   /// forcefully. As an effect, on the next rendering cycle its @b
   /// calculate() (see #Evas_Smart_Class) smart function will be called.
   ///
   /// @see evas_object_smart_need_recalculate_set().
   /// @see evas_object_smart_calculate().
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   void changed() const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_changed());
   }

   /// @brief Removes a member object from a given smart object.
   ///
   /// This removes a member object from a smart object, if it was added
   /// to any. The object will still be on the canvas, but no longer
   /// associated with whichever smart object it was associated with.
   ///
   /// @see evas_object_smart_member_add() for more details
   /// @see evas_object_smart_members_get()
   ///
   /// @param sub_obj the member object
   /// @ingroup Evas_Smart_Object_Group
   ///
   void member_del(Evas_Object * sub_obj) const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_member_del(sub_obj));
   }

   /// @brief Deletes a smart object.
   ///
   void del() const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_del());
   }

   /// @brief Attach a given smart data to a given smart object.
   ///
   /// @param s 
   ///
   void attach(Evas_Smart * s) const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_attach(s));
   }

   /// @brief Get the value of the flag signalling that a given smart object needs to
   /// get recalculated.
   ///
   /// @return if flag is set or not.
   ///
   /// @note this flag will be unset during the rendering phase, when the
   /// @c calculate() smart function is called, if one is provided.
   /// If it's not provided, then the flag will be left unchanged
   /// after the rendering phase.
   ///
   /// @see evas_object_smart_need_recalculate_set(), for more details
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param value whether one wants to set (@c EINA_TRUE) or to unset
   /// (@c EINA_FALSE) the flag.
   ///
   Eina_Bool need_recalculate_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_smart_need_recalculate_get());
      return _tmp_ret;
   }

   /// @brief Set or unset the flag signalling that a given smart object needs to
   /// get recalculated.
   ///
   /// If this flag is set, then the @c calculate() smart function of @p
   /// obj will be called, if one is provided, during rendering phase of
   /// Evas (see evas_render()), after which this flag will be
   /// automatically unset.
   ///
   /// If that smart function is not provided for the given object, this
   /// flag will be left unchanged.
   ///
   /// @note just setting this flag will not make the canvas' whole scene
   /// dirty, by itself, and evas_render() will have no effect. To
   /// force that, use evas_object_smart_changed(), that will also
   /// call this function automatically, with @c EINA_TRUE as parameter.
   ///
   /// @see evas_object_smart_need_recalculate_get()
   /// @see evas_object_smart_calculate()
   /// @see evas_smart_objects_calculate()
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param value whether one wants to set (@c EINA_TRUE) or to unset
   /// (@c EINA_FALSE) the flag.
   ///
   void need_recalculate_set(Eina_Bool value) const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_need_recalculate_set(value));
   }

   /// @brief No description supplied by the EAPI.
   ///
   /// @param clip 
   ///
   void clip_set(Evas_Object * clip) const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_clip_set(clip));
   }

   /// @brief No description supplied by the EAPI.
   ///
   /// @param r 
   /// @param g 
   /// @param b 
   /// @param a 
   ///
   void color_set(int r, int g, int b, int a) const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_color_set(r, g, b, a));
   }

   /// @brief Store a pointer to user data for a given smart object.
   ///
   /// This data is stored @b independently of the one set by
   /// evas_object_data_set(), naturally.
   ///
   /// @see evas_object_smart_data_get()
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param data A pointer to user data
   ///
   void data_set(void * data) const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_data_set(data));
   }

   /// @brief Retrieves the list of the member objects of a given Evas smart
   /// object
   ///
   /// @return Returns the list of the member objects of @p obj.
   ///
   /// The returned list should be freed with @c eina_list_free() when you
   /// no longer need it.
   ///
   /// @since 1.7 This function will return @c NULL when a non-smart object is passed.
   ///
   /// @see evas_object_smart_member_add()
   /// @see evas_object_smart_member_del()
   /// @see evas_object_smart_iterator_new()
   ///
   Eina_List * members_get() const
   {
      Eina_List * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_smart_members_get());
      return _tmp_ret;
   }

   /// @brief Get the #Evas_Smart from which @p obj smart object was created.
   ///
   /// @return the #Evas_Smart handle or @c NULL, on errors
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   Evas_Smart * smart_get() const
   {
      Evas_Smart * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_smart_smart_get());
      return _tmp_ret;
   }

   static Eo_Class const* _eo_class()
   {
      return(EVAS_OBJ_SMART_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(EVAS_OBJ_SMART_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
void evas_smart_show_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->show();
}

template <typename T>
void evas_smart_move_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord x, Evas_Coord y)
{
   static_cast<T*>(self->this_)->move(x, y);
}

template <typename T>
Eina_Bool evas_smart_callbacks_descriptions_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const Evas_Smart_Cb_Description * descriptions)
{
   return static_cast<T*>(self->this_)->callbacks_descriptions_set(descriptions);
}

template <typename T>
void evas_smart_callbacks_descriptions_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const Evas_Smart_Cb_Description *** class_descriptions, unsigned int* class_count, const Evas_Smart_Cb_Description *** instance_descriptions, unsigned int* instance_count)
{
   static_cast<T*>(self->this_)->callbacks_descriptions_get(class_descriptions, class_count, instance_descriptions, instance_count);
}

template <typename T>
Eina_Iterator * evas_smart_iterator_new_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->iterator_new();
}

template <typename T>
void evas_smart_callback_description_find_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * name, const Evas_Smart_Cb_Description ** class_description, const Evas_Smart_Cb_Description ** instance_description)
{
   static_cast<T*>(self->this_)->callback_description_find(name, class_description, instance_description);
}

template <typename T>
void evas_smart_hide_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->hide();
}

template <typename T>
void evas_smart_calculate_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->calculate();
}

template <typename T>
void evas_smart_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->add();
}

template <typename T>
void evas_smart_member_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * sub_obj)
{
   static_cast<T*>(self->this_)->member_add(sub_obj);
}

template <typename T>
void evas_smart_resize_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord w, Evas_Coord h)
{
   static_cast<T*>(self->this_)->resize(w, h);
}

template <typename T>
void evas_smart_clip_unset_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->clip_unset();
}

template <typename T>
void evas_smart_changed_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->changed();
}

template <typename T>
void evas_smart_member_del_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * sub_obj)
{
   static_cast<T*>(self->this_)->member_del(sub_obj);
}

template <typename T>
void evas_smart_del_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->del();
}

template <typename T>
void evas_smart_attach_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Smart * s)
{
   static_cast<T*>(self->this_)->attach(s);
}

template <typename T>
Eina_Bool evas_smart_need_recalculate_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->need_recalculate_get();
}

template <typename T>
void evas_smart_need_recalculate_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool value)
{
   static_cast<T*>(self->this_)->need_recalculate_set(value);
}

template <typename T>
void evas_smart_clip_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * clip)
{
   static_cast<T*>(self->this_)->clip_set(clip);
}

template <typename T>
void evas_smart_color_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int r, int g, int b, int a)
{
   static_cast<T*>(self->this_)->color_set(r, g, b, a);
}

template <typename T>
void evas_smart_data_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, void * data)
{
   static_cast<T*>(self->this_)->data_set(data);
}

template <typename T>
Eina_List * evas_smart_members_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->members_get();
}

template <typename T>
Evas_Smart * evas_smart_smart_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->smart_get();
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::evas_smart >
{
   template <typename T>
   struct type
   {
      virtual void show()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_smart_show());
      }

      virtual void move(Evas_Coord x, Evas_Coord y)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_smart_move(x, y));
      }

      virtual Eina_Bool callbacks_descriptions_set(const Evas_Smart_Cb_Description * descriptions)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_smart_callbacks_descriptions_set(descriptions));
         return _tmp_ret;
      }

      virtual void callbacks_descriptions_get(const Evas_Smart_Cb_Description *** class_descriptions, unsigned int* class_count, const Evas_Smart_Cb_Description *** instance_descriptions, unsigned int* instance_count)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_smart_callbacks_descriptions_get(class_descriptions, class_count, instance_descriptions, instance_count));
      }

      virtual Eina_Iterator * iterator_new()
      {
         Eina_Iterator * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_smart_iterator_new());
         return _tmp_ret;
      }

      virtual void callback_description_find(const char * name, const Evas_Smart_Cb_Description ** class_description, const Evas_Smart_Cb_Description ** instance_description)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_smart_callback_description_find(name, class_description, instance_description));
      }

      virtual void hide()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_smart_hide());
      }

      virtual void calculate()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_smart_calculate());
      }

      virtual void add()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_smart_add());
      }

      virtual void member_add(Evas_Object * sub_obj)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_smart_member_add(sub_obj));
      }

      virtual void resize(Evas_Coord w, Evas_Coord h)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_smart_resize(w, h));
      }

      virtual void clip_unset()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_smart_clip_unset());
      }

      virtual void changed()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_smart_changed());
      }

      virtual void member_del(Evas_Object * sub_obj)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_smart_member_del(sub_obj));
      }

      virtual void del()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_smart_del());
      }

      virtual void attach(Evas_Smart * s)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_smart_attach(s));
      }

      virtual Eina_Bool need_recalculate_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_smart_need_recalculate_get());
         return _tmp_ret;
      }

      virtual void need_recalculate_set(Eina_Bool value)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_smart_need_recalculate_set(value));
      }

      virtual void clip_set(Evas_Object * clip)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_smart_clip_set(clip));
      }

      virtual void color_set(int r, int g, int b, int a)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_smart_color_set(r, g, b, a));
      }

      virtual void data_set(void * data)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_smart_data_set(data));
      }

      virtual Eina_List * members_get()
      {
         Eina_List * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_smart_members_get());
         return _tmp_ret;
      }

      virtual Evas_Smart * smart_get()
      {
         Evas_Smart * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_smart_smart_get());
         return _tmp_ret;
      }

   };
};


template<>
struct operation_description_class_size< ::evas_smart >
{
   static const int value = 23;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::evas_smart>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::evas_smart_show_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_show);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::evas_smart_move_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_move);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::evas_smart_callbacks_descriptions_set_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_callbacks_descriptions_set);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::evas_smart_callbacks_descriptions_get_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_callbacks_descriptions_get);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::evas_smart_iterator_new_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_iterator_new);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::evas_smart_callback_description_find_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_callback_description_find);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::evas_smart_hide_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_hide);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::evas_smart_calculate_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_calculate);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::evas_smart_add_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_add);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::evas_smart_member_add_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_member_add);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::evas_smart_resize_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_resize);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::evas_smart_clip_unset_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_clip_unset);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::evas_smart_changed_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_changed);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::evas_smart_member_del_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_member_del);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::evas_smart_del_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_del);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::evas_smart_attach_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_attach);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::evas_smart_need_recalculate_get_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_need_recalculate_get);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   ops[17].func = reinterpret_cast<void*>(& ::evas_smart_need_recalculate_set_wrapper<T>);
   ops[17].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_need_recalculate_set);
   ops[17].op = EO_OP_OVERRIDE;
   ops[17].op_type = EO_OP_TYPE_REGULAR;
   ops[17].doc = NULL;

   ops[18].func = reinterpret_cast<void*>(& ::evas_smart_clip_set_wrapper<T>);
   ops[18].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_clip_set);
   ops[18].op = EO_OP_OVERRIDE;
   ops[18].op_type = EO_OP_TYPE_REGULAR;
   ops[18].doc = NULL;

   ops[19].func = reinterpret_cast<void*>(& ::evas_smart_color_set_wrapper<T>);
   ops[19].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_color_set);
   ops[19].op = EO_OP_OVERRIDE;
   ops[19].op_type = EO_OP_TYPE_REGULAR;
   ops[19].doc = NULL;

   ops[20].func = reinterpret_cast<void*>(& ::evas_smart_data_set_wrapper<T>);
   ops[20].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_data_set);
   ops[20].op = EO_OP_OVERRIDE;
   ops[20].op_type = EO_OP_TYPE_REGULAR;
   ops[20].doc = NULL;

   ops[21].func = reinterpret_cast<void*>(& ::evas_smart_members_get_wrapper<T>);
   ops[21].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_members_get);
   ops[21].op = EO_OP_OVERRIDE;
   ops[21].op_type = EO_OP_TYPE_REGULAR;
   ops[21].doc = NULL;

   ops[22].func = reinterpret_cast<void*>(& ::evas_smart_smart_get_wrapper<T>);
   ops[22].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_smart_get);
   ops[22].op = EO_OP_OVERRIDE;
   ops[22].op_type = EO_OP_TYPE_REGULAR;
   ops[22].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::evas_smart >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::evas_smart, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

template<>
struct extension_inheritance< ::evas_smart>
{
   template <typename T>
   struct type
   {
      operator ::evas_smart() const
      {
         return ::evas_smart(eo_ref(static_cast<T const*>(this)->_eo_ptr()));
      }

      void show()
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_smart_show());
      }

      void move(Evas_Coord x, Evas_Coord y)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_smart_move(x, y));
      }

      Eina_Bool callbacks_descriptions_set(const Evas_Smart_Cb_Description * descriptions)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_smart_callbacks_descriptions_set(descriptions));
         return _tmp_ret;
      }

      void callbacks_descriptions_get(const Evas_Smart_Cb_Description *** class_descriptions, unsigned int* class_count, const Evas_Smart_Cb_Description *** instance_descriptions, unsigned int* instance_count)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_smart_callbacks_descriptions_get(class_descriptions, class_count, instance_descriptions, instance_count));
      }

      Eina_Iterator * iterator_new()
      {
         Eina_Iterator * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_smart_iterator_new());
         return _tmp_ret;
      }

      void callback_description_find(const char * name, const Evas_Smart_Cb_Description ** class_description, const Evas_Smart_Cb_Description ** instance_description)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_smart_callback_description_find(name, class_description, instance_description));
      }

      void hide()
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_smart_hide());
      }

      void calculate()
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_smart_calculate());
      }

      void add()
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_smart_add());
      }

      void member_add(Evas_Object * sub_obj)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_smart_member_add(sub_obj));
      }

      void resize(Evas_Coord w, Evas_Coord h)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_smart_resize(w, h));
      }

      void clip_unset()
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_smart_clip_unset());
      }

      void changed()
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_smart_changed());
      }

      void member_del(Evas_Object * sub_obj)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_smart_member_del(sub_obj));
      }

      void del()
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_smart_del());
      }

      void attach(Evas_Smart * s)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_smart_attach(s));
      }

      Eina_Bool need_recalculate_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_smart_need_recalculate_get());
         return _tmp_ret;
      }

      void need_recalculate_set(Eina_Bool value)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_smart_need_recalculate_set(value));
      }

      void clip_set(Evas_Object * clip)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_smart_clip_set(clip));
      }

      void color_set(int r, int g, int b, int a)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_smart_color_set(r, g, b, a));
      }

      void data_set(void * data)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_smart_data_set(data));
      }

      Eina_List * members_get()
      {
         Eina_List * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_smart_members_get());
         return _tmp_ret;
      }

      Evas_Smart * smart_get()
      {
         Evas_Smart * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_smart_smart_get());
         return _tmp_ret;
      }

   };
};

inline Eo_Class const* get_eo_class(tag<::evas_smart>)
{
   return (EVAS_OBJ_SMART_CLASS);
}

} } }
#endif // EFL_GENERATED_EVAS_SMART_HH

