#ifndef EFL_GENERATED_EVAS_TABLE_HH
#define EFL_GENERATED_EVAS_TABLE_HH

#include <Eo.h>
#include <Eo.hh>

extern "C"
{
#include "canvas/evas_table.eo.h"
}

#include "canvas/evas_smart_clipped.eo.hh"

struct evas_table
      : evas_smart_clipped
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit evas_table(Eo* eo)
      : evas_smart_clipped(eo)
   {}

   evas_table(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : evas_table(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   evas_table(evas_table const& other)
      : evas_smart_clipped(eo_ref(other._eo_ptr()))
   {}

   ~evas_table() {}

   /// @brief Faster way to remove all child objects from a table object.
   ///
   /// @param clear if true, it will delete just removed children.
   ///
   void clear(Eina_Bool clear) const
   {
      eo_do(_eo_ptr(), ::evas_obj_table_clear(clear));
   }

   /// @brief Get an accessor to get random access to the list of children for the table.
   ///
   /// @note Do not remove or delete objects while walking the list.
   ///
   Eina_Accessor * accessor_new() const
   {
      Eina_Accessor * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_table_accessor_new());
      return _tmp_ret;
   }

   /// @brief Get an iterator to walk the list of children for the table.
   ///
   /// @note Do not remove or delete objects while walking the list.
   ///
   Eina_Iterator * iterator_new() const
   {
      Eina_Iterator * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_table_iterator_new());
      return _tmp_ret;
   }

   /// @brief @brief Create a table that is child of a given element @a parent.
   ///
   /// @see evas_object_table_add()
   ///
   Evas_Object * add_to() const
   {
      Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_table_add_to());
      return _tmp_ret;
   }

   /// @brief Get packing location of a child of table
   ///
   /// @return 1 on success, 0 on failure.
   /// @since 1.1
   ///
   /// @param child The child object to add.
   /// @param[out] col pointer to store relative-horizontal position to place child.
   /// @param[out] row pointer to store relative-vertical position to place child.
   /// @param[out] colspan pointer to store how many relative-horizontal position to use for this child.
   /// @param[out] rowspan pointer to store how many relative-vertical position to use for this child.
   ///
   Eina_Bool pack_get(Evas_Object * child, unsigned short* col, unsigned short* row, unsigned short* colspan, unsigned short* rowspan) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_table_pack_get(child, col, row, colspan, rowspan));
      return _tmp_ret;
   }

   /// @brief Add a new child to a table object or set its current packing.
   ///
   /// Note that columns and rows only guarantee 16bit unsigned values at best.
   /// That means that col + colspan AND row + rowspan must fit inside 16bit
   /// unsigned values cleanly. You will be warned once values exceed 15bit
   /// storage, and attempting to use values not able to fit in 16bits will
   /// result in failure.
   ///
   /// @return 1 on success, 0 on failure.
   ///
   /// @param child The child object to add.
   /// @param col relative-horizontal position to place child.
   /// @param row relative-vertical position to place child.
   /// @param colspan how many relative-horizontal position to use for this child.
   /// @param rowspan how many relative-vertical position to use for this child.
   ///
   Eina_Bool pack(Evas_Object * child, unsigned short col, unsigned short row, unsigned short colspan, unsigned short rowspan) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_table_pack(child, col, row, colspan, rowspan));
      return _tmp_ret;
   }

   /// @brief Remove child from table.
   ///
   /// @note removing a child will immediately call a walk over children in order
   /// to recalculate numbers of columns and rows. If you plan to remove
   /// all children, use evas_object_table_clear() instead.
   ///
   /// @return 1 on success, 0 on failure.
   ///
   /// @param child 
   ///
   Eina_Bool unpack(Evas_Object * child) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_table_unpack(child));
      return _tmp_ret;
   }

   /// @brief Get the current layout homogeneous mode.
   ///
   /// @see evas_object_table_homogeneous_set()
   ///
   /// @param homogeneous 
   ///
   Evas_Object_Table_Homogeneous_Mode homogeneous_get() const
   {
      Evas_Object_Table_Homogeneous_Mode _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_table_homogeneous_get());
      return _tmp_ret;
   }

   /// @brief @brief Set how this table should layout children.
   ///
   /// @todo consider aspect hint and respect it.
   ///
   /// @par EVAS_OBJECT_TABLE_HOMOGENEOUS_NONE
   /// If table does not use homogeneous mode then columns and rows will
   /// be calculated based on hints of individual cells. This operation
   /// mode is more flexible, but more complex and heavy to calculate as
   /// well. @b Weight properties are handled as a boolean expand. Negative
   /// alignment will be considered as 0.5. This is the default.
   ///
   /// @todo @c EVAS_OBJECT_TABLE_HOMOGENEOUS_NONE should balance weight.
   ///
   /// @par EVAS_OBJECT_TABLE_HOMOGENEOUS_TABLE
   /// When homogeneous is relative to table the own table size is divided
   /// equally among children, filling the whole table area. That is, if
   /// table has @c WIDTH and @c COLUMNS, each cell will get <tt>WIDTH /
   /// COLUMNS</tt> pixels. If children have minimum size that is larger
   /// than this amount (including padding), then it will overflow and be
   /// aligned respecting the alignment hint, possible overlapping sibling
   /// cells. @b Weight hint is used as a boolean, if greater than zero it
   /// will make the child expand in that axis, taking as much space as
   /// possible (bounded to maximum size hint). Negative alignment will be
   /// considered as 0.5.
   ///
   /// @par EVAS_OBJECT_TABLE_HOMOGENEOUS_ITEM
   /// When homogeneous is relative to item it means the greatest minimum
   /// cell size will be used. That is, if no element is set to expand,
   /// the table will have its contents to a minimum size, the bounding
   /// box of all these children will be aligned relatively to the table
   /// object using evas_object_table_align_get(). If the table area is
   /// too small to hold this minimum bounding box, then the objects will
   /// keep their size and the bounding box will overflow the box area,
   /// still respecting the alignment. @b Weight hint is used as a
   /// boolean, if greater than zero it will make that cell expand in that
   /// axis, toggling the <b>expand mode</b>, which makes the table behave
   /// much like @b EVAS_OBJECT_TABLE_HOMOGENEOUS_TABLE, except that the
   /// bounding box will overflow and items will not overlap siblings. If
   /// no minimum size is provided at all then the table will fallback to
   /// expand mode as well.
   ///
   /// @param homogeneous 
   ///
   void homogeneous_set(Evas_Object_Table_Homogeneous_Mode homogeneous) const
   {
      eo_do(_eo_ptr(), ::evas_obj_table_homogeneous_set(homogeneous));
   }

   /// @brief Get alignment of the whole bounding box of contents.
   ///
   /// @param horizontal 
   /// @param vertical 
   ///
   void align_get(double* horizontal, double* vertical) const
   {
      eo_do(_eo_ptr(), ::evas_obj_table_align_get(horizontal, vertical));
   }

   /// @brief Set the alignment of the whole bounding box of contents.
   ///
   /// @param horizontal 
   /// @param vertical 
   ///
   void align_set(double horizontal, double vertical) const
   {
      eo_do(_eo_ptr(), ::evas_obj_table_align_set(horizontal, vertical));
   }

   /// @brief Get padding between cells.
   ///
   /// @param horizontal 
   /// @param vertical 
   ///
   void padding_get(Evas_Coord* horizontal, Evas_Coord* vertical) const
   {
      eo_do(_eo_ptr(), ::evas_obj_table_padding_get(horizontal, vertical));
   }

   /// @brief Set padding between cells.
   ///
   /// @param horizontal 
   /// @param vertical 
   ///
   void padding_set(Evas_Coord horizontal, Evas_Coord vertical) const
   {
      eo_do(_eo_ptr(), ::evas_obj_table_padding_set(horizontal, vertical));
   }

   /// @brief Gets the mirrored mode of the table.
   ///
   /// @return @c EINA_TRUE if it's a mirrored table, @c EINA_FALSE otherwise.
   /// @since 1.1
   /// @see evas_object_table_mirrored_set()
   ///
   /// @param mirrored the mirrored mode to set
   ///
   Eina_Bool mirrored_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_table_mirrored_get());
      return _tmp_ret;
   }

   /// @brief Sets the mirrored mode of the table. In mirrored mode the table items go
   /// from right to left instead of left to right. That is, 1,1 is top right, not
   /// top left.
   ///
   /// @since 1.1
   ///
   /// @param mirrored the mirrored mode to set
   ///
   void mirrored_set(Eina_Bool mirrored) const
   {
      eo_do(_eo_ptr(), ::evas_obj_table_mirrored_set(mirrored));
   }

   /// @brief Get the number of columns and rows this table takes.
   ///
   /// @note columns and rows are virtual entities, one can specify a table
   /// with a single object that takes 4 columns and 5 rows. The only
   /// difference for a single cell table is that paddings will be
   /// accounted proportionally.
   ///
   /// @param cols 
   /// @param rows 
   ///
   void col_row_size_get(int* cols, int* rows) const
   {
      eo_do(_eo_ptr(), ::evas_obj_table_col_row_size_get(cols, rows));
   }

   /// @brief Get the list of children for the table.
   ///
   /// @note This is a duplicate of the list kept by the table internally.
   /// It's up to the user to destroy it when it no longer needs it.
   /// It's possible to remove objects from the table when walking this
   /// list, but these removals won't be reflected on it.
   ///
   Eina_List * children_get() const
   {
      Eina_List * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_table_children_get());
      return _tmp_ret;
   }

   /// @brief Get the child of the table at the given coordinates
   ///
   /// @note This does not take into account col/row spanning
   ///
   /// @param child 
   ///
   Evas_Object * child_get(unsigned short col, unsigned short row) const
   {
      Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_table_child_get(col, row));
      return _tmp_ret;
   }

   static Eo_Class const* _eo_class()
   {
      return(EVAS_OBJ_TABLE_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(EVAS_OBJ_TABLE_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
void evas_table_clear_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool clear)
{
   static_cast<T*>(self->this_)->clear(clear);
}

template <typename T>
Eina_Accessor * evas_table_accessor_new_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->accessor_new();
}

template <typename T>
Eina_Iterator * evas_table_iterator_new_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->iterator_new();
}

template <typename T>
Evas_Object * evas_table_add_to_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->add_to();
}

template <typename T>
Eina_Bool evas_table_pack_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * child, unsigned short* col, unsigned short* row, unsigned short* colspan, unsigned short* rowspan)
{
   return static_cast<T*>(self->this_)->pack_get(child, col, row, colspan, rowspan);
}

template <typename T>
Eina_Bool evas_table_pack_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * child, unsigned short col, unsigned short row, unsigned short colspan, unsigned short rowspan)
{
   return static_cast<T*>(self->this_)->pack(child, col, row, colspan, rowspan);
}

template <typename T>
Eina_Bool evas_table_unpack_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * child)
{
   return static_cast<T*>(self->this_)->unpack(child);
}

template <typename T>
Evas_Object_Table_Homogeneous_Mode evas_table_homogeneous_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->homogeneous_get();
}

template <typename T>
void evas_table_homogeneous_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object_Table_Homogeneous_Mode homogeneous)
{
   static_cast<T*>(self->this_)->homogeneous_set(homogeneous);
}

template <typename T>
void evas_table_align_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double* horizontal, double* vertical)
{
   static_cast<T*>(self->this_)->align_get(horizontal, vertical);
}

template <typename T>
void evas_table_align_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double horizontal, double vertical)
{
   static_cast<T*>(self->this_)->align_set(horizontal, vertical);
}

template <typename T>
void evas_table_padding_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord* horizontal, Evas_Coord* vertical)
{
   static_cast<T*>(self->this_)->padding_get(horizontal, vertical);
}

template <typename T>
void evas_table_padding_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord horizontal, Evas_Coord vertical)
{
   static_cast<T*>(self->this_)->padding_set(horizontal, vertical);
}

template <typename T>
Eina_Bool evas_table_mirrored_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->mirrored_get();
}

template <typename T>
void evas_table_mirrored_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool mirrored)
{
   static_cast<T*>(self->this_)->mirrored_set(mirrored);
}

template <typename T>
void evas_table_col_row_size_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int* cols, int* rows)
{
   static_cast<T*>(self->this_)->col_row_size_get(cols, rows);
}

template <typename T>
Eina_List * evas_table_children_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->children_get();
}

template <typename T>
Evas_Object * evas_table_child_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, unsigned short col, unsigned short row)
{
   return static_cast<T*>(self->this_)->child_get(col, row);
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::evas_table >
{
   template <typename T>
   struct type
   {
      virtual void clear(Eina_Bool clear)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_table_clear(clear));
      }

      virtual Eina_Accessor * accessor_new()
      {
         Eina_Accessor * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_table_accessor_new());
         return _tmp_ret;
      }

      virtual Eina_Iterator * iterator_new()
      {
         Eina_Iterator * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_table_iterator_new());
         return _tmp_ret;
      }

      virtual Evas_Object * add_to()
      {
         Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_table_add_to());
         return _tmp_ret;
      }

      virtual Eina_Bool pack_get(Evas_Object * child, unsigned short* col, unsigned short* row, unsigned short* colspan, unsigned short* rowspan)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_table_pack_get(child, col, row, colspan, rowspan));
         return _tmp_ret;
      }

      virtual Eina_Bool pack(Evas_Object * child, unsigned short col, unsigned short row, unsigned short colspan, unsigned short rowspan)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_table_pack(child, col, row, colspan, rowspan));
         return _tmp_ret;
      }

      virtual Eina_Bool unpack(Evas_Object * child)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_table_unpack(child));
         return _tmp_ret;
      }

      virtual Evas_Object_Table_Homogeneous_Mode homogeneous_get()
      {
         Evas_Object_Table_Homogeneous_Mode _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_table_homogeneous_get());
         return _tmp_ret;
      }

      virtual void homogeneous_set(Evas_Object_Table_Homogeneous_Mode homogeneous)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_table_homogeneous_set(homogeneous));
      }

      virtual void align_get(double* horizontal, double* vertical)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_table_align_get(horizontal, vertical));
      }

      virtual void align_set(double horizontal, double vertical)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_table_align_set(horizontal, vertical));
      }

      virtual void padding_get(Evas_Coord* horizontal, Evas_Coord* vertical)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_table_padding_get(horizontal, vertical));
      }

      virtual void padding_set(Evas_Coord horizontal, Evas_Coord vertical)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_table_padding_set(horizontal, vertical));
      }

      virtual Eina_Bool mirrored_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_table_mirrored_get());
         return _tmp_ret;
      }

      virtual void mirrored_set(Eina_Bool mirrored)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_table_mirrored_set(mirrored));
      }

      virtual void col_row_size_get(int* cols, int* rows)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_table_col_row_size_get(cols, rows));
      }

      virtual Eina_List * children_get()
      {
         Eina_List * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_table_children_get());
         return _tmp_ret;
      }

      virtual Evas_Object * child_get(unsigned short col, unsigned short row)
      {
         Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_table_child_get(col, row));
         return _tmp_ret;
      }

   };
};


template<>
struct operation_description_class_size< ::evas_table >
{
   static const int value = 18;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::evas_table>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::evas_table_clear_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::evas_obj_table_clear);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::evas_table_accessor_new_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::evas_obj_table_accessor_new);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::evas_table_iterator_new_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::evas_obj_table_iterator_new);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::evas_table_add_to_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::evas_obj_table_add_to);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::evas_table_pack_get_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::evas_obj_table_pack_get);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::evas_table_pack_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::evas_obj_table_pack);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::evas_table_unpack_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::evas_obj_table_unpack);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::evas_table_homogeneous_get_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::evas_obj_table_homogeneous_get);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::evas_table_homogeneous_set_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::evas_obj_table_homogeneous_set);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::evas_table_align_get_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::evas_obj_table_align_get);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::evas_table_align_set_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::evas_obj_table_align_set);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::evas_table_padding_get_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::evas_obj_table_padding_get);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::evas_table_padding_set_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::evas_obj_table_padding_set);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::evas_table_mirrored_get_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::evas_obj_table_mirrored_get);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::evas_table_mirrored_set_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::evas_obj_table_mirrored_set);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::evas_table_col_row_size_get_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::evas_obj_table_col_row_size_get);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::evas_table_children_get_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::evas_obj_table_children_get);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   ops[17].func = reinterpret_cast<void*>(& ::evas_table_child_get_wrapper<T>);
   ops[17].api_func = reinterpret_cast<void*>(& ::evas_obj_table_child_get);
   ops[17].op = EO_OP_OVERRIDE;
   ops[17].op_type = EO_OP_TYPE_REGULAR;
   ops[17].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::evas_table >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::evas_table, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

template<>
struct extension_inheritance< ::evas_table>
{
   template <typename T>
   struct type
   {
      operator ::evas_table() const
      {
         return ::evas_table(eo_ref(static_cast<T const*>(this)->_eo_ptr()));
      }

      void clear(Eina_Bool clear)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_table_clear(clear));
      }

      Eina_Accessor * accessor_new()
      {
         Eina_Accessor * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_table_accessor_new());
         return _tmp_ret;
      }

      Eina_Iterator * iterator_new()
      {
         Eina_Iterator * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_table_iterator_new());
         return _tmp_ret;
      }

      Evas_Object * add_to()
      {
         Evas_Object * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_table_add_to());
         return _tmp_ret;
      }

      Eina_Bool pack_get(Evas_Object * child, unsigned short* col, unsigned short* row, unsigned short* colspan, unsigned short* rowspan)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_table_pack_get(child, col, row, colspan, rowspan));
         return _tmp_ret;
      }

      Eina_Bool pack(Evas_Object * child, unsigned short col, unsigned short row, unsigned short colspan, unsigned short rowspan)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_table_pack(child, col, row, colspan, rowspan));
         return _tmp_ret;
      }

      Eina_Bool unpack(Evas_Object * child)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_table_unpack(child));
         return _tmp_ret;
      }

      Evas_Object_Table_Homogeneous_Mode homogeneous_get()
      {
         Evas_Object_Table_Homogeneous_Mode _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_table_homogeneous_get());
         return _tmp_ret;
      }

      void homogeneous_set(Evas_Object_Table_Homogeneous_Mode homogeneous)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_table_homogeneous_set(homogeneous));
      }

      void align_get(double* horizontal, double* vertical)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_table_align_get(horizontal, vertical));
      }

      void align_set(double horizontal, double vertical)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_table_align_set(horizontal, vertical));
      }

      void padding_get(Evas_Coord* horizontal, Evas_Coord* vertical)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_table_padding_get(horizontal, vertical));
      }

      void padding_set(Evas_Coord horizontal, Evas_Coord vertical)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_table_padding_set(horizontal, vertical));
      }

      Eina_Bool mirrored_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_table_mirrored_get());
         return _tmp_ret;
      }

      void mirrored_set(Eina_Bool mirrored)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_table_mirrored_set(mirrored));
      }

      void col_row_size_get(int* cols, int* rows)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_table_col_row_size_get(cols, rows));
      }

      Eina_List * children_get()
      {
         Eina_List * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_table_children_get());
         return _tmp_ret;
      }

      Evas_Object * child_get(unsigned short col, unsigned short row)
      {
         Evas_Object * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_table_child_get(col, row));
         return _tmp_ret;
      }

   };
};

inline Eo_Class const* get_eo_class(tag<::evas_table>)
{
   return (EVAS_OBJ_TABLE_CLASS);
}

} } }
#endif // EFL_GENERATED_EVAS_TABLE_HH

