#ifndef EFL_GENERATED_EVAS_TEXTBLOCK_HH
#define EFL_GENERATED_EVAS_TEXTBLOCK_HH

#include <Eo.h>
#include <Eo.hh>

extern "C"
{
#include "canvas/evas_textblock.eo.h"
}

#include "canvas/evas_object.eo.hh"

struct evas_textblock
      : evas_object
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit evas_textblock(Eo* eo)
      : evas_object(eo)
   {}

   evas_textblock(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : evas_textblock(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   evas_textblock(evas_textblock const& other)
      : evas_object(eo_ref(other._eo_ptr()))
   {}

   ~evas_textblock() {}

   /// @brief Get the geometry of a line number.
   ///
   /// @return @c EINA_TRUE on success, @c EINA_FALSE otherwise.
   ///
   /// @param line the line number.
   /// @param[out] cx x coord of the line.
   /// @param[out] cy y coord of the line.
   /// @param[out] cw w coord of the line.
   /// @param[out] ch h coord of the line.
   ///
   Eina_Bool line_number_geometry_get(int line, Evas_Coord* cx, Evas_Coord* cy, Evas_Coord* cw, Evas_Coord* ch) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_textblock_line_number_geometry_get(line, cx, cy, cw, ch));
      return _tmp_ret;
   }

   /// @brief @brief Get the "replacement character" for given textblock object. Returns
   /// @c NULL if no replacement character is in use.
   ///
   /// @return Replacement character or @c NULL.
   ///
   const char * replace_char_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_textblock_replace_char_get());
      return _tmp_ret;
   }

   /// @brief Del the from the top of the user style stack.
   ///
   /// @see evas_object_textblock_style_get
   /// @since 1.2
   ///
   void style_user_pop() const
   {
      eo_do(_eo_ptr(), ::evas_obj_textblock_style_user_pop());
   }

   /// @brief Create a new cursor, associate it to the obj and init it to point
   /// to the start of the textblock. Association to the object means the cursor
   /// will be updated when the object will change.
   ///
   /// @note if you need speed and you know what you are doing, it's slightly faster to just allocate the cursor yourself and not associate it. (only people developing the actual object, and not users of the object).
   ///
   /// @return the new cursor.
   ///
   Evas_Textblock_Cursor * cursor_new() const
   {
      Evas_Textblock_Cursor * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_textblock_cursor_new());
      return _tmp_ret;
   }

   /// @brief No description supplied by the EAPI.
   ///
   /// @param anchor 
   ///
   const Eina_List * node_format_list_get(const char * anchor) const
   {
      const Eina_List * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_textblock_node_format_list_get(anchor));
      return _tmp_ret;
   }

   /// @brief Get (don't remove) the style at the top of the user style stack.
   ///
   /// @return the style of the object.
   /// @see evas_object_textblock_style_get
   /// @since 1.2
   ///
   const Evas_Textblock_Style * style_user_peek() const
   {
      const Evas_Textblock_Style * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_textblock_style_user_peek());
      return _tmp_ret;
   }

   /// @brief Remove a format node and its match.
   ///
   /// @param n 
   ///
   void node_format_remove_pair(Evas_Object_Textblock_Node_Format * n) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textblock_node_format_remove_pair(n));
   }

   /// @brief Clear the textblock object.
   /// @note Does NOT* free the Evas object itself.
   ///
   /// @return nothing.
   ///
   void clear() const
   {
      eo_do(_eo_ptr(), ::evas_obj_textblock_clear());
   }

   /// @brief Push ts to the top of the user style stack.
   ///
   /// FIXME: API is solid but currently only supports 1 style in the stack.
   ///
   /// The user style overrides the corresponding elements of the regular style.
   /// This is the proper way to do theme overrides in code.
   /// @return Returns no value.
   /// @see evas_object_textblock_style_set
   /// @since 1.2
   ///
   /// @param ts the style to set.
   ///
   void style_user_push(Evas_Textblock_Style * ts) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textblock_style_user_push(ts));
   }

   /// @brief Return the markup of the object.
   ///
   /// @return the markup text of the object.
   ///
   /// @param text the markup text to use.
   ///
   const char * text_markup_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_textblock_text_markup_get());
      return _tmp_ret;
   }

   /// @brief Sets the tetxblock's text to the markup text.
   ///
   /// @note assumes text does not include the unicode object replacement char (0xFFFC)
   ///
   /// @return Return no value.
   ///
   /// @param text the markup text to use.
   ///
   void text_markup_set(const char * text) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textblock_text_markup_set(text));
   }

   /// @brief @brief Gets the vertical alignment of a textblock
   ///
   /// @return The alignment set for the object.
   /// @since 1.1
   ///
   /// @param align A value between @c 0.0 and @c 1.0.
   ///
   double valign_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_textblock_valign_get());
      return _tmp_ret;
   }

   /// @brief @brief Sets the vertical alignment of text within the textblock object
   /// as a whole.
   ///
   /// Normally alignment is 0.0 (top of object). Values given should be
   /// between 0.0 and 1.0 (1.0 bottom of object, 0.5 being vertically centered
   /// etc.).
   ///
   /// @since 1.1
   ///
   /// @param align A value between @c 0.0 and @c 1.0.
   ///
   void valign_set(double align) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textblock_valign_set(align));
   }

   /// @brief @brief Gets the BiDi delimiters used in the textblock.
   ///
   /// BiDi delimiters are use for in-paragraph separation of bidi segments. This
   /// is useful for example in recipients fields of e-mail clients where bidi
   /// oddities can occur when mixing RTL and LTR.
   ///
   /// @return A null terminated string of delimiters, e.g ",|". If empty, returns
   /// @c NULL.
   /// @since 1.1
   ///
   /// @param delim A null terminated string of delimiters, e.g ",|".
   ///
   const char * bidi_delimiters_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_textblock_bidi_delimiters_get());
      return _tmp_ret;
   }

   /// @brief @brief Sets the BiDi delimiters used in the textblock.
   ///
   /// BiDi delimiters are use for in-paragraph separation of bidi segments. This
   /// is useful for example in recipients fields of e-mail clients where bidi
   /// oddities can occur when mixing RTL and LTR.
   ///
   /// @since 1.1
   ///
   /// @param delim A null terminated string of delimiters, e.g ",|".
   ///
   void bidi_delimiters_set(const char * delim) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textblock_bidi_delimiters_set(delim));
   }

   /// @brief @brief Set the "replacement character" to use for the given textblock object.
   ///
   /// @param ch The charset name.
   ///
   void replace_char_set(const char * ch) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textblock_replace_char_set(ch));
   }

   /// @brief @brief Gets newline mode. When true, newline character behaves
   /// as a paragraph separator.
   ///
   /// @return @c EINA_TRUE if in legacy mode, @c EINA_FALSE otherwise.
   /// @since 1.1
   ///
   /// @param mode @c EINA_TRUE for legacy mode, @c EINA_FALSE otherwise.
   ///
   Eina_Bool legacy_newline_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_textblock_legacy_newline_get());
      return _tmp_ret;
   }

   /// @brief @brief Sets newline mode. When true, newline character will behave
   /// as a paragraph separator.
   ///
   /// @since 1.1
   ///
   /// @param mode @c EINA_TRUE for legacy mode, @c EINA_FALSE otherwise.
   ///
   void legacy_newline_set(Eina_Bool mode) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textblock_legacy_newline_set(mode));
   }

   /// @brief Return the style of an object.
   /// @return the style of the object.
   ///
   /// @param ts the style to set.
   ///
   const Evas_Textblock_Style * style_get() const
   {
      const Evas_Textblock_Style * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_textblock_style_get());
      return _tmp_ret;
   }

   /// @brief Set the objects style to ts.
   /// @return Returns no value.
   ///
   /// @param ts the style to set.
   ///
   void style_set(const Evas_Textblock_Style * ts) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textblock_style_set(ts));
   }

   /// @brief Returns the first format node.
   ///
   /// @param format 
   ///
   const Evas_Object_Textblock_Node_Format * node_format_first_get() const
   {
      const Evas_Object_Textblock_Node_Format * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_textblock_node_format_first_get());
      return _tmp_ret;
   }

   /// @brief Get the formatted width and height. This calculates the actual size after restricting
   /// the textblock to the current size of the object.
   /// The main difference between this and @ref evas_object_textblock_size_native_get
   /// is that the "native" function does not wrapping into account
   /// it just calculates the real width of the object if it was placed on an
   /// infinite canvas, while this function gives the size after wrapping
   /// according to the size restrictions of the object.
   ///
   /// For example for a textblock containing the text: "You shall not pass!"
   /// with no margins or padding and assuming a monospace font and a size of
   /// 7x10 char widths (for simplicity) has a native size of 19x1
   /// and a formatted size of 5x4.
   ///
   ///
   /// @return Returns no value.
   /// @see evas_object_textblock_size_native_get
   ///
   /// @param w the width of the object.
   /// @param h the height of the object
   ///
   void size_formatted_get(Evas_Coord* w, Evas_Coord* h) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textblock_size_formatted_get(w, h));
   }

   /// @brief Returns the last format node.
   ///
   /// @param format 
   ///
   const Evas_Object_Textblock_Node_Format * node_format_last_get() const
   {
      const Evas_Object_Textblock_Node_Format * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_textblock_node_format_last_get());
      return _tmp_ret;
   }

   /// @brief Return the object's main cursor.
   ///
   /// @return The @p obj's main cursor.
   ///
   Evas_Textblock_Cursor * cursor_get() const
   {
      Evas_Textblock_Cursor * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_textblock_cursor_get());
      return _tmp_ret;
   }

   /// @brief Get the native width and height. This calculates the actual size without taking account
   /// the current size of the object.
   /// The main difference between this and @ref evas_object_textblock_size_formatted_get
   /// is that the "native" function does not take wrapping into account
   /// it just calculates the real width of the object if it was placed on an
   /// infinite canvas, while the "formatted" function gives the size after
   /// wrapping text according to the size restrictions of the object.
   ///
   /// For example for a textblock containing the text: "You shall not pass!"
   /// with no margins or padding and assuming a monospace font and a size of
   /// 7x10 char widths (for simplicity) has a native size of 19x1
   /// and a formatted size of 5x4.
   ///
   /// @return Returns no value.
   ///
   /// @param w the width returned
   /// @param h the height returned
   ///
   void size_native_get(Evas_Coord* w, Evas_Coord* h) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textblock_size_native_get(w, h));
   }

   /// @brief No description supplied by the EAPI.
   ///
   /// @param l 
   /// @param r 
   /// @param t 
   /// @param b 
   ///
   void style_insets_get(Evas_Coord* l, Evas_Coord* r, Evas_Coord* t, Evas_Coord* b) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textblock_style_insets_get(l, r, t, b));
   }

   static Eo_Class const* _eo_class()
   {
      return(EVAS_OBJ_TEXTBLOCK_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(EVAS_OBJ_TEXTBLOCK_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
Eina_Bool evas_textblock_line_number_geometry_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int line, Evas_Coord* cx, Evas_Coord* cy, Evas_Coord* cw, Evas_Coord* ch)
{
   return static_cast<T*>(self->this_)->line_number_geometry_get(line, cx, cy, cw, ch);
}

template <typename T>
const char * evas_textblock_replace_char_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->replace_char_get();
}

template <typename T>
void evas_textblock_style_user_pop_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->style_user_pop();
}

template <typename T>
Evas_Textblock_Cursor * evas_textblock_cursor_new_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->cursor_new();
}

template <typename T>
const Eina_List * evas_textblock_node_format_list_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * anchor)
{
   return static_cast<T*>(self->this_)->node_format_list_get(anchor);
}

template <typename T>
const Evas_Textblock_Style * evas_textblock_style_user_peek_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->style_user_peek();
}

template <typename T>
void evas_textblock_node_format_remove_pair_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object_Textblock_Node_Format * n)
{
   static_cast<T*>(self->this_)->node_format_remove_pair(n);
}

template <typename T>
void evas_textblock_clear_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->clear();
}

template <typename T>
void evas_textblock_style_user_push_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Textblock_Style * ts)
{
   static_cast<T*>(self->this_)->style_user_push(ts);
}

template <typename T>
const char * evas_textblock_text_markup_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->text_markup_get();
}

template <typename T>
void evas_textblock_text_markup_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * text)
{
   static_cast<T*>(self->this_)->text_markup_set(text);
}

template <typename T>
double evas_textblock_valign_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->valign_get();
}

template <typename T>
void evas_textblock_valign_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double align)
{
   static_cast<T*>(self->this_)->valign_set(align);
}

template <typename T>
const char * evas_textblock_bidi_delimiters_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->bidi_delimiters_get();
}

template <typename T>
void evas_textblock_bidi_delimiters_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * delim)
{
   static_cast<T*>(self->this_)->bidi_delimiters_set(delim);
}

template <typename T>
void evas_textblock_replace_char_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * ch)
{
   static_cast<T*>(self->this_)->replace_char_set(ch);
}

template <typename T>
Eina_Bool evas_textblock_legacy_newline_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->legacy_newline_get();
}

template <typename T>
void evas_textblock_legacy_newline_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool mode)
{
   static_cast<T*>(self->this_)->legacy_newline_set(mode);
}

template <typename T>
const Evas_Textblock_Style * evas_textblock_style_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->style_get();
}

template <typename T>
void evas_textblock_style_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const Evas_Textblock_Style * ts)
{
   static_cast<T*>(self->this_)->style_set(ts);
}

template <typename T>
const Evas_Object_Textblock_Node_Format * evas_textblock_node_format_first_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->node_format_first_get();
}

template <typename T>
void evas_textblock_size_formatted_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord* w, Evas_Coord* h)
{
   static_cast<T*>(self->this_)->size_formatted_get(w, h);
}

template <typename T>
const Evas_Object_Textblock_Node_Format * evas_textblock_node_format_last_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->node_format_last_get();
}

template <typename T>
Evas_Textblock_Cursor * evas_textblock_cursor_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->cursor_get();
}

template <typename T>
void evas_textblock_size_native_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord* w, Evas_Coord* h)
{
   static_cast<T*>(self->this_)->size_native_get(w, h);
}

template <typename T>
void evas_textblock_style_insets_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord* l, Evas_Coord* r, Evas_Coord* t, Evas_Coord* b)
{
   static_cast<T*>(self->this_)->style_insets_get(l, r, t, b);
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::evas_textblock >
{
   template <typename T>
   struct type
   {
      virtual Eina_Bool line_number_geometry_get(int line, Evas_Coord* cx, Evas_Coord* cy, Evas_Coord* cw, Evas_Coord* ch)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_textblock_line_number_geometry_get(line, cx, cy, cw, ch));
         return _tmp_ret;
      }

      virtual const char * replace_char_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_textblock_replace_char_get());
         return _tmp_ret;
      }

      virtual void style_user_pop()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_textblock_style_user_pop());
      }

      virtual Evas_Textblock_Cursor * cursor_new()
      {
         Evas_Textblock_Cursor * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_textblock_cursor_new());
         return _tmp_ret;
      }

      virtual const Eina_List * node_format_list_get(const char * anchor)
      {
         const Eina_List * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_textblock_node_format_list_get(anchor));
         return _tmp_ret;
      }

      virtual const Evas_Textblock_Style * style_user_peek()
      {
         const Evas_Textblock_Style * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_textblock_style_user_peek());
         return _tmp_ret;
      }

      virtual void node_format_remove_pair(Evas_Object_Textblock_Node_Format * n)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_textblock_node_format_remove_pair(n));
      }

      virtual void clear()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_textblock_clear());
      }

      virtual void style_user_push(Evas_Textblock_Style * ts)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_textblock_style_user_push(ts));
      }

      virtual const char * text_markup_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_textblock_text_markup_get());
         return _tmp_ret;
      }

      virtual void text_markup_set(const char * text)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_textblock_text_markup_set(text));
      }

      virtual double valign_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_textblock_valign_get());
         return _tmp_ret;
      }

      virtual void valign_set(double align)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_textblock_valign_set(align));
      }

      virtual const char * bidi_delimiters_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_textblock_bidi_delimiters_get());
         return _tmp_ret;
      }

      virtual void bidi_delimiters_set(const char * delim)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_textblock_bidi_delimiters_set(delim));
      }

      virtual void replace_char_set(const char * ch)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_textblock_replace_char_set(ch));
      }

      virtual Eina_Bool legacy_newline_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_textblock_legacy_newline_get());
         return _tmp_ret;
      }

      virtual void legacy_newline_set(Eina_Bool mode)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_textblock_legacy_newline_set(mode));
      }

      virtual const Evas_Textblock_Style * style_get()
      {
         const Evas_Textblock_Style * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_textblock_style_get());
         return _tmp_ret;
      }

      virtual void style_set(const Evas_Textblock_Style * ts)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_textblock_style_set(ts));
      }

      virtual const Evas_Object_Textblock_Node_Format * node_format_first_get()
      {
         const Evas_Object_Textblock_Node_Format * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_textblock_node_format_first_get());
         return _tmp_ret;
      }

      virtual void size_formatted_get(Evas_Coord* w, Evas_Coord* h)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_textblock_size_formatted_get(w, h));
      }

      virtual const Evas_Object_Textblock_Node_Format * node_format_last_get()
      {
         const Evas_Object_Textblock_Node_Format * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_textblock_node_format_last_get());
         return _tmp_ret;
      }

      virtual Evas_Textblock_Cursor * cursor_get()
      {
         Evas_Textblock_Cursor * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_textblock_cursor_get());
         return _tmp_ret;
      }

      virtual void size_native_get(Evas_Coord* w, Evas_Coord* h)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_textblock_size_native_get(w, h));
      }

      virtual void style_insets_get(Evas_Coord* l, Evas_Coord* r, Evas_Coord* t, Evas_Coord* b)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_textblock_style_insets_get(l, r, t, b));
      }

   };
};


template<>
struct operation_description_class_size< ::evas_textblock >
{
   static const int value = 26;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::evas_textblock>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::evas_textblock_line_number_geometry_get_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_line_number_geometry_get);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::evas_textblock_replace_char_get_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_replace_char_get);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::evas_textblock_style_user_pop_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_style_user_pop);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::evas_textblock_cursor_new_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_cursor_new);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::evas_textblock_node_format_list_get_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_node_format_list_get);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::evas_textblock_style_user_peek_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_style_user_peek);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::evas_textblock_node_format_remove_pair_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_node_format_remove_pair);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::evas_textblock_clear_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_clear);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::evas_textblock_style_user_push_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_style_user_push);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::evas_textblock_text_markup_get_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_text_markup_get);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::evas_textblock_text_markup_set_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_text_markup_set);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::evas_textblock_valign_get_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_valign_get);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::evas_textblock_valign_set_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_valign_set);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::evas_textblock_bidi_delimiters_get_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_bidi_delimiters_get);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::evas_textblock_bidi_delimiters_set_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_bidi_delimiters_set);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::evas_textblock_replace_char_set_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_replace_char_set);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::evas_textblock_legacy_newline_get_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_legacy_newline_get);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   ops[17].func = reinterpret_cast<void*>(& ::evas_textblock_legacy_newline_set_wrapper<T>);
   ops[17].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_legacy_newline_set);
   ops[17].op = EO_OP_OVERRIDE;
   ops[17].op_type = EO_OP_TYPE_REGULAR;
   ops[17].doc = NULL;

   ops[18].func = reinterpret_cast<void*>(& ::evas_textblock_style_get_wrapper<T>);
   ops[18].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_style_get);
   ops[18].op = EO_OP_OVERRIDE;
   ops[18].op_type = EO_OP_TYPE_REGULAR;
   ops[18].doc = NULL;

   ops[19].func = reinterpret_cast<void*>(& ::evas_textblock_style_set_wrapper<T>);
   ops[19].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_style_set);
   ops[19].op = EO_OP_OVERRIDE;
   ops[19].op_type = EO_OP_TYPE_REGULAR;
   ops[19].doc = NULL;

   ops[20].func = reinterpret_cast<void*>(& ::evas_textblock_node_format_first_get_wrapper<T>);
   ops[20].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_node_format_first_get);
   ops[20].op = EO_OP_OVERRIDE;
   ops[20].op_type = EO_OP_TYPE_REGULAR;
   ops[20].doc = NULL;

   ops[21].func = reinterpret_cast<void*>(& ::evas_textblock_size_formatted_get_wrapper<T>);
   ops[21].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_size_formatted_get);
   ops[21].op = EO_OP_OVERRIDE;
   ops[21].op_type = EO_OP_TYPE_REGULAR;
   ops[21].doc = NULL;

   ops[22].func = reinterpret_cast<void*>(& ::evas_textblock_node_format_last_get_wrapper<T>);
   ops[22].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_node_format_last_get);
   ops[22].op = EO_OP_OVERRIDE;
   ops[22].op_type = EO_OP_TYPE_REGULAR;
   ops[22].doc = NULL;

   ops[23].func = reinterpret_cast<void*>(& ::evas_textblock_cursor_get_wrapper<T>);
   ops[23].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_cursor_get);
   ops[23].op = EO_OP_OVERRIDE;
   ops[23].op_type = EO_OP_TYPE_REGULAR;
   ops[23].doc = NULL;

   ops[24].func = reinterpret_cast<void*>(& ::evas_textblock_size_native_get_wrapper<T>);
   ops[24].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_size_native_get);
   ops[24].op = EO_OP_OVERRIDE;
   ops[24].op_type = EO_OP_TYPE_REGULAR;
   ops[24].doc = NULL;

   ops[25].func = reinterpret_cast<void*>(& ::evas_textblock_style_insets_get_wrapper<T>);
   ops[25].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_style_insets_get);
   ops[25].op = EO_OP_OVERRIDE;
   ops[25].op_type = EO_OP_TYPE_REGULAR;
   ops[25].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::evas_textblock >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::evas_textblock, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

template<>
struct extension_inheritance< ::evas_textblock>
{
   template <typename T>
   struct type
   {
      operator ::evas_textblock() const
      {
         return ::evas_textblock(eo_ref(static_cast<T const*>(this)->_eo_ptr()));
      }

      Eina_Bool line_number_geometry_get(int line, Evas_Coord* cx, Evas_Coord* cy, Evas_Coord* cw, Evas_Coord* ch)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_textblock_line_number_geometry_get(line, cx, cy, cw, ch));
         return _tmp_ret;
      }

      const char * replace_char_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_textblock_replace_char_get());
         return _tmp_ret;
      }

      void style_user_pop()
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_textblock_style_user_pop());
      }

      Evas_Textblock_Cursor * cursor_new()
      {
         Evas_Textblock_Cursor * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_textblock_cursor_new());
         return _tmp_ret;
      }

      const Eina_List * node_format_list_get(const char * anchor)
      {
         const Eina_List * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_textblock_node_format_list_get(anchor));
         return _tmp_ret;
      }

      const Evas_Textblock_Style * style_user_peek()
      {
         const Evas_Textblock_Style * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_textblock_style_user_peek());
         return _tmp_ret;
      }

      void node_format_remove_pair(Evas_Object_Textblock_Node_Format * n)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_textblock_node_format_remove_pair(n));
      }

      void clear()
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_textblock_clear());
      }

      void style_user_push(Evas_Textblock_Style * ts)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_textblock_style_user_push(ts));
      }

      const char * text_markup_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_textblock_text_markup_get());
         return _tmp_ret;
      }

      void text_markup_set(const char * text)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_textblock_text_markup_set(text));
      }

      double valign_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_textblock_valign_get());
         return _tmp_ret;
      }

      void valign_set(double align)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_textblock_valign_set(align));
      }

      const char * bidi_delimiters_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_textblock_bidi_delimiters_get());
         return _tmp_ret;
      }

      void bidi_delimiters_set(const char * delim)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_textblock_bidi_delimiters_set(delim));
      }

      void replace_char_set(const char * ch)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_textblock_replace_char_set(ch));
      }

      Eina_Bool legacy_newline_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_textblock_legacy_newline_get());
         return _tmp_ret;
      }

      void legacy_newline_set(Eina_Bool mode)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_textblock_legacy_newline_set(mode));
      }

      const Evas_Textblock_Style * style_get()
      {
         const Evas_Textblock_Style * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_textblock_style_get());
         return _tmp_ret;
      }

      void style_set(const Evas_Textblock_Style * ts)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_textblock_style_set(ts));
      }

      const Evas_Object_Textblock_Node_Format * node_format_first_get()
      {
         const Evas_Object_Textblock_Node_Format * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_textblock_node_format_first_get());
         return _tmp_ret;
      }

      void size_formatted_get(Evas_Coord* w, Evas_Coord* h)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_textblock_size_formatted_get(w, h));
      }

      const Evas_Object_Textblock_Node_Format * node_format_last_get()
      {
         const Evas_Object_Textblock_Node_Format * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_textblock_node_format_last_get());
         return _tmp_ret;
      }

      Evas_Textblock_Cursor * cursor_get()
      {
         Evas_Textblock_Cursor * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_textblock_cursor_get());
         return _tmp_ret;
      }

      void size_native_get(Evas_Coord* w, Evas_Coord* h)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_textblock_size_native_get(w, h));
      }

      void style_insets_get(Evas_Coord* l, Evas_Coord* r, Evas_Coord* t, Evas_Coord* b)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_textblock_style_insets_get(l, r, t, b));
      }

   };
};

inline Eo_Class const* get_eo_class(tag<::evas_textblock>)
{
   return (EVAS_OBJ_TEXTBLOCK_CLASS);
}

} } }
#endif // EFL_GENERATED_EVAS_TEXTBLOCK_HH

