#ifndef EFL_GENERATED_EVAS_TEXTGRID_HH
#define EFL_GENERATED_EVAS_TEXTGRID_HH

#include <Eo.h>
#include <Eo.hh>

extern "C"
{
#include "canvas/evas_textgrid.eo.h"
}

#include "canvas/evas_object.eo.hh"

struct evas_textgrid
      : evas_object
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit evas_textgrid(Eo* eo)
      : evas_object(eo)
   {}

   evas_textgrid(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : evas_textgrid(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   evas_textgrid(evas_textgrid const& other)
      : evas_object(eo_ref(other._eo_ptr()))
   {}

   ~evas_textgrid() {}

   /// @brief @brief Indicate for evas that part of a textgrid region (cells) has been updated.
   ///
   /// This function declares to evas that a region of cells was updated by
   /// code and needs refreshing. An application should modify cells like this
   /// as an example:
   ///
   /// @code
   /// Evas_Textgrid_Cell cells;
   /// int i;
   ///
   /// cells = evas_object_textgrid_cellrow_get(obj, row);
   /// for (i = 0; i < width; i++) cells[i].codepoint = 'E';
   /// evas_object_textgrid_cellrow_set(obj, row, cells);
   /// evas_object_textgrid_update_add(obj, 0, row, width, 1);
   /// @endcode
   ///
   /// @see evas_object_textgrid_cellrow_set()
   /// @see evas_object_textgrid_cellrow_get()
   /// @see evas_object_textgrid_size_set()
   ///
   /// @since 1.7
   ///
   /// @param x The rect region of cells top-left x (column)
   /// @param y The rect region of cells top-left y (row)
   /// @param w The rect region size in number of cells (columns)
   /// @param h The rect region size in number of cells (rows)
   ///
   void update_add(int x, int y, int w, int h) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textgrid_update_add(x, y, w, h));
   }

   /// @brief @brief Set the string at the given row of the given textgrid object.
   ///
   /// This function returns cells to the textgrid taken by
   /// evas_object_textgrid_cellrow_get(). The row pointer @p row should be the
   /// same row pointer returned by evas_object_textgrid_cellrow_get() for the
   /// same row @p y.
   ///
   /// @see evas_object_textgrid_cellrow_get()
   /// @see evas_object_textgrid_size_set()
   /// @see evas_object_textgrid_update_add()
   ///
   /// @since 1.7
   ///
   /// @param y The row index of the grid.
   /// @param row The string as a sequence of #Evas_Textgrid_Cell.
   ///
   void cellrow_set(int y, const Evas_Textgrid_Cell * row) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textgrid_cellrow_set(y, row));
   }

   /// @brief @brief Get the string at the given row of the given textgrid object.
   ///
   /// @return A pointer to the first cell of the given row.
   ///
   /// This function returns a pointer to the first cell of the line @p y
   /// of the textgrid object @p obj. If @p y is not between 0 and the
   /// number of lines of the grid - 1, or on error, this function return @c NULL.
   ///
   /// @see evas_object_textgrid_cellrow_set()
   /// @see evas_object_textgrid_size_set()
   /// @see evas_object_textgrid_update_add()
   ///
   /// @since 1.7
   ///
   /// @param y The row index of the grid.
   ///
   Evas_Textgrid_Cell * cellrow_get(int y) const
   {
      Evas_Textgrid_Cell * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_textgrid_cellrow_get(y));
      return _tmp_ret;
   }

   /// @brief @brief The set color to the given palette at the given index of the given textgrid object.
   ///
   /// This function sets the color for the palette of type @p pal at the
   /// index @p idx of the textgrid object @p obj. The ARGB components are
   /// given by @p r, @p g, @p b and @p a. This color can be used when
   /// setting the #Evas_Textgrid_Cell structure. The components must set
   /// a pre-multiplied color. If pal is #EVAS_TEXTGRID_PALETTE_NONE or
   /// #EVAS_TEXTGRID_PALETTE_LAST, or if @p idx is not between 0 and 255,
   /// or on error, this function does nothing. The color components are
   /// clamped between 0 and 255. If @p idx is greater than the latest set
   /// color, the colors between this last index and @p idx - 1 are set to
   /// black (0, 0, 0, 0).
   ///
   /// @see evas_object_textgrid_palette_get()
   ///
   /// @since 1.7
   ///
   /// @param pal The type of the palette to set the color.
   /// @param idx The index of the paletter to which the color is stored.
   /// @param r The red component of the color.
   /// @param g The green component of the color.
   /// @param b The blue component of the color.
   /// @param a The alpha component of the color.
   ///
   void palette_set(Evas_Textgrid_Palette pal, int idx, int r, int g, int b, int a) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textgrid_palette_set(pal, idx, r, g, b, a));
   }

   /// @brief @brief The retrieve color to the given palette at the given index of the given textgrid object.
   ///
   /// This function retrieves the color for the palette of type @p pal at the
   /// index @p idx of the textgrid object @p obj. The ARGB components are
   /// stored in the buffers @p r, @p g, @p b and @p a. If @p idx is not
   /// between 0 and the index of the latest set color, or if @p pal is
   /// #EVAS_TEXTGRID_PALETTE_NONE or #EVAS_TEXTGRID_PALETTE_LAST, the
   /// values of the components are 0. @p r, @p g, @p b and @p a can be
   /// @c NULL.
   ///
   /// @see evas_object_textgrid_palette_set()
   ///
   /// @since 1.7
   ///
   /// @param pal The type of the palette to set the color.
   /// @param idx The index of the palette to which the color is stored.
   /// @param[out] r A pointer to the red component of the color.
   /// @param[out] g A pointer to the green component of the color.
   /// @param[out] b A pointer to the blue component of the color.
   /// @param[out] a A pointer to the alpha component of the color.
   ///
   void palette_get(Evas_Textgrid_Palette pal, int idx, int* r, int* g, int* b, int* a) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textgrid_palette_get(pal, idx, r, g, b, a));
   }

   /// @brief @brief Get the font file's path which is being used on a given textgrid object.
   ///
   /// @return The font file's path.
   ///
   /// This function returns the font source path of the textgrid object
   /// @p obj. If the font source path has not been set, or on error,
   /// @c NULL is returned.
   ///
   /// @see evas_object_textgrid_font_get()
   /// @see evas_object_textgrid_font_set()
   /// @see evas_object_textgrid_font_source_set()
   ///
   /// @since 1.7
   ///
   /// @param font_source The font file's path.
   ///
   const char * font_source_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_textgrid_font_source_get());
      return _tmp_ret;
   }

   /// @brief @brief Set the font (source) file to be used on a given textgrid object.
   ///
   /// This function allows the font file @p font_source to be explicitly
   /// set for the textgrid object @p obj, overriding system lookup, which
   /// will first occur in the given file's contents. If @p font_source is
   /// @c NULL or is an empty string, or the same font_source has already
   /// been set, or on error, this function does nothing.
   ///
   /// @see evas_object_textgrid_font_get()
   /// @see evas_object_textgrid_font_set()
   /// @see evas_object_textgrid_font_source_get()
   ///
   /// @since 1.7
   ///
   /// @param font_source The font file's path.
   ///
   void font_source_set(const char * font_source) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textgrid_font_source_set(font_source));
   }

   /// @brief No description supplied by the EAPI.
   ///
   /// @param styles 
   ///
   Evas_Textgrid_Font_Style supported_font_styles_get() const
   {
      Evas_Textgrid_Font_Style _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_textgrid_supported_font_styles_get());
      return _tmp_ret;
   }

   /// @brief No description supplied by the EAPI.
   ///
   /// @param styles 
   ///
   void supported_font_styles_set(Evas_Textgrid_Font_Style styles) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textgrid_supported_font_styles_set(styles));
   }

   /// @brief @brief Retrieve the font family and size in use on a given textgrid object.
   ///
   /// This function allows the font name and size of a textgrid object
   /// @p obj to be queried and stored respectively in the buffers
   /// @p font_name and @p font_size. Be aware that the font name string is
   /// still owned by Evas and should @b not have free() called on it by
   /// the caller of the function. On error, the font name is the empty
   /// string and the font size is 0. @p font_name and @p font_source can
   /// be @c NULL.
   ///
   /// @see evas_object_textgrid_font_set()
   /// @see evas_object_textgrid_font_source_set()
   /// @see evas_object_textgrid_font_source_get()
   ///
   /// @since 1.7
   ///
   /// @param font_name The font (family) name.
   /// @param font_size The font size, in points.
   ///
   void font_get(const char ** font_name, Evas_Font_Size* font_size) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textgrid_font_get(font_name, font_size));
   }

   /// @brief @brief Set the font family and size on a given textgrid object.
   ///
   /// This function allows the font name @p font_name and size
   /// @p font_size of the textgrid object @p obj to be set. The @p font_name
   /// string has to follow fontconfig's convention on naming fonts, as
   /// it's the underlying library used to query system fonts by Evas (see
   /// the @c fc-list command's output, on your system, to get an
   /// idea). It also has to be a monospace font. If @p font_name is
   /// @c NULL, or if it is an empty string, or if @p font_size is less or
   /// equal than 0, or on error, this function does nothing.
   ///
   /// @see evas_object_textgrid_font_get()
   /// @see evas_object_textgrid_font_source_set()
   /// @see evas_object_textgrid_font_source_get()
   ///
   /// @since 1.7
   ///
   /// @param font_name The font (family) name.
   /// @param font_size The font size, in points.
   ///
   void font_set(const char * font_name, Evas_Font_Size font_size) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textgrid_font_set(font_name, font_size));
   }

   /// @brief @brief Get the size of the textgrid object.
   ///
   /// This function retrieves the number of lines in the buffer @p
   /// h and the number of columns in the buffer @p w of
   /// the textgrid object @p obj. @p w or @p h can be
   /// @c NULL. On error, their value is 0.
   ///
   /// @since 1.7
   ///
   /// @param w The number of columns (width in cells) of the grid.
   /// @param h The number of rows (height in cells) of the grid.
   ///
   void size_get(int* w, int* h) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textgrid_size_get(w, h));
   }

   /// @brief @brief Set the size of the textgrid object.
   ///
   /// This function sets the number of lines @p h and the number
   /// of columns @p w to the textgrid object @p obj. If
   /// @p w or @p h are less or equal than 0, this
   /// functiond does nothing.
   ///
   /// @since 1.7
   ///
   /// @param w The number of columns (width in cells) of the grid.
   /// @param h The number of rows (height in cells) of the grid.
   ///
   void size_set(int w, int h) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textgrid_size_set(w, h));
   }

   /// @brief @brief Retrieve the size of a cell of the given textgrid object in pixels.
   ///
   /// This functions retrieves the width and height, in pixels, of a cell
   /// of the textgrid object @p obj and store them respectively in the
   /// buffers @p width and @p height. Their value depends on the
   /// monospace font used for the textgrid object, as well as the
   /// style. @p width and @p height can be @c NULL. On error, they are
   /// set to 0.
   ///
   /// @see evas_object_textgrid_font_set()
   /// @see evas_object_textgrid_supported_font_styles_set()
   ///
   /// @since 1.7
   ///
   /// @param width A pointer to the location to store the width in pixels of a cell.
   /// @param height A pointer to the location to store the height in
   /// pixels of a cell.
   ///
   void cell_size_get(int* width, int* height) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textgrid_cell_size_get(width, height));
   }

   static Eo_Class const* _eo_class()
   {
      return(EVAS_OBJ_TEXTGRID_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(EVAS_OBJ_TEXTGRID_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
void evas_textgrid_update_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int x, int y, int w, int h)
{
   static_cast<T*>(self->this_)->update_add(x, y, w, h);
}

template <typename T>
void evas_textgrid_cellrow_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int y, const Evas_Textgrid_Cell * row)
{
   static_cast<T*>(self->this_)->cellrow_set(y, row);
}

template <typename T>
Evas_Textgrid_Cell * evas_textgrid_cellrow_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int y)
{
   return static_cast<T*>(self->this_)->cellrow_get(y);
}

template <typename T>
void evas_textgrid_palette_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Textgrid_Palette pal, int idx, int r, int g, int b, int a)
{
   static_cast<T*>(self->this_)->palette_set(pal, idx, r, g, b, a);
}

template <typename T>
void evas_textgrid_palette_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Textgrid_Palette pal, int idx, int* r, int* g, int* b, int* a)
{
   static_cast<T*>(self->this_)->palette_get(pal, idx, r, g, b, a);
}

template <typename T>
const char * evas_textgrid_font_source_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->font_source_get();
}

template <typename T>
void evas_textgrid_font_source_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * font_source)
{
   static_cast<T*>(self->this_)->font_source_set(font_source);
}

template <typename T>
Evas_Textgrid_Font_Style evas_textgrid_supported_font_styles_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->supported_font_styles_get();
}

template <typename T>
void evas_textgrid_supported_font_styles_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Textgrid_Font_Style styles)
{
   static_cast<T*>(self->this_)->supported_font_styles_set(styles);
}

template <typename T>
void evas_textgrid_font_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char ** font_name, Evas_Font_Size* font_size)
{
   static_cast<T*>(self->this_)->font_get(font_name, font_size);
}

template <typename T>
void evas_textgrid_font_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * font_name, Evas_Font_Size font_size)
{
   static_cast<T*>(self->this_)->font_set(font_name, font_size);
}

template <typename T>
void evas_textgrid_size_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int* w, int* h)
{
   static_cast<T*>(self->this_)->size_get(w, h);
}

template <typename T>
void evas_textgrid_size_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int w, int h)
{
   static_cast<T*>(self->this_)->size_set(w, h);
}

template <typename T>
void evas_textgrid_cell_size_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int* width, int* height)
{
   static_cast<T*>(self->this_)->cell_size_get(width, height);
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::evas_textgrid >
{
   template <typename T>
   struct type
   {
      virtual void update_add(int x, int y, int w, int h)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_textgrid_update_add(x, y, w, h));
      }

      virtual void cellrow_set(int y, const Evas_Textgrid_Cell * row)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_textgrid_cellrow_set(y, row));
      }

      virtual Evas_Textgrid_Cell * cellrow_get(int y)
      {
         Evas_Textgrid_Cell * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_textgrid_cellrow_get(y));
         return _tmp_ret;
      }

      virtual void palette_set(Evas_Textgrid_Palette pal, int idx, int r, int g, int b, int a)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_textgrid_palette_set(pal, idx, r, g, b, a));
      }

      virtual void palette_get(Evas_Textgrid_Palette pal, int idx, int* r, int* g, int* b, int* a)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_textgrid_palette_get(pal, idx, r, g, b, a));
      }

      virtual const char * font_source_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_textgrid_font_source_get());
         return _tmp_ret;
      }

      virtual void font_source_set(const char * font_source)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_textgrid_font_source_set(font_source));
      }

      virtual Evas_Textgrid_Font_Style supported_font_styles_get()
      {
         Evas_Textgrid_Font_Style _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , _tmp_ret = ::evas_obj_textgrid_supported_font_styles_get());
         return _tmp_ret;
      }

      virtual void supported_font_styles_set(Evas_Textgrid_Font_Style styles)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_textgrid_supported_font_styles_set(styles));
      }

      virtual void font_get(const char ** font_name, Evas_Font_Size* font_size)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_textgrid_font_get(font_name, font_size));
      }

      virtual void font_set(const char * font_name, Evas_Font_Size font_size)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_textgrid_font_set(font_name, font_size));
      }

      virtual void size_get(int* w, int* h)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_textgrid_size_get(w, h));
      }

      virtual void size_set(int w, int h)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_textgrid_size_set(w, h));
      }

      virtual void cell_size_get(int* width, int* height)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr()
            , static_cast<T*>(this)->_eo_class()
            , ::evas_obj_textgrid_cell_size_get(width, height));
      }

   };
};


template<>
struct operation_description_class_size< ::evas_textgrid >
{
   static const int value = 14;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::evas_textgrid>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::evas_textgrid_update_add_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_update_add);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::evas_textgrid_cellrow_set_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_cellrow_set);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::evas_textgrid_cellrow_get_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_cellrow_get);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::evas_textgrid_palette_set_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_palette_set);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::evas_textgrid_palette_get_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_palette_get);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::evas_textgrid_font_source_get_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_font_source_get);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::evas_textgrid_font_source_set_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_font_source_set);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::evas_textgrid_supported_font_styles_get_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_supported_font_styles_get);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::evas_textgrid_supported_font_styles_set_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_supported_font_styles_set);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::evas_textgrid_font_get_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_font_get);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::evas_textgrid_font_set_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_font_set);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::evas_textgrid_size_get_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_size_get);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::evas_textgrid_size_set_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_size_set);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::evas_textgrid_cell_size_get_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_cell_size_get);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::evas_textgrid >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::evas_textgrid, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

template<>
struct extension_inheritance< ::evas_textgrid>
{
   template <typename T>
   struct type
   {
      operator ::evas_textgrid() const
      {
         return ::evas_textgrid(eo_ref(static_cast<T const*>(this)->_eo_ptr()));
      }

      void update_add(int x, int y, int w, int h)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_textgrid_update_add(x, y, w, h));
      }

      void cellrow_set(int y, const Evas_Textgrid_Cell * row)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_textgrid_cellrow_set(y, row));
      }

      Evas_Textgrid_Cell * cellrow_get(int y)
      {
         Evas_Textgrid_Cell * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_textgrid_cellrow_get(y));
         return _tmp_ret;
      }

      void palette_set(Evas_Textgrid_Palette pal, int idx, int r, int g, int b, int a)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_textgrid_palette_set(pal, idx, r, g, b, a));
      }

      void palette_get(Evas_Textgrid_Palette pal, int idx, int* r, int* g, int* b, int* a)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_textgrid_palette_get(pal, idx, r, g, b, a));
      }

      const char * font_source_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_textgrid_font_source_get());
         return _tmp_ret;
      }

      void font_source_set(const char * font_source)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_textgrid_font_source_set(font_source));
      }

      Evas_Textgrid_Font_Style supported_font_styles_get()
      {
         Evas_Textgrid_Font_Style _tmp_ret = {};
         eo_do(static_cast<T*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_textgrid_supported_font_styles_get());
         return _tmp_ret;
      }

      void supported_font_styles_set(Evas_Textgrid_Font_Style styles)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_textgrid_supported_font_styles_set(styles));
      }

      void font_get(const char ** font_name, Evas_Font_Size* font_size)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_textgrid_font_get(font_name, font_size));
      }

      void font_set(const char * font_name, Evas_Font_Size font_size)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_textgrid_font_set(font_name, font_size));
      }

      void size_get(int* w, int* h)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_textgrid_size_get(w, h));
      }

      void size_set(int w, int h)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_textgrid_size_set(w, h));
      }

      void cell_size_get(int* width, int* height)
      {
         eo_do(static_cast<T*>(this)->_eo_ptr(), ::evas_obj_textgrid_cell_size_get(width, height));
      }

   };
};

inline Eo_Class const* get_eo_class(tag<::evas_textgrid>)
{
   return (EVAS_OBJ_TEXTGRID_CLASS);
}

} } }
#endif // EFL_GENERATED_EVAS_TEXTGRID_HH

